000100 IDENTIFICATION DIVISION.
000200 PROGRAM-ID. MML2AB.
000201*       RELEASE DATE=08/24/01.        REVISION LEVEL=08.06      * ++++++++
000202***************************************************************** ++++++++
000203*WARNING.  THIS COMPUTER PROGRAM IS PROTECTED BY COPYRIGHT LAW  * ++++++++
000204*AND INTERNATIONAL TREATIES.  UNAUTHORIZED REPRODUCTION OR      * ++++++++
000205*DISTRIBUTION OF THIS PROGRAM, OR ANY PORTION OF IT, MAY RESULT * ++++++++
000206*IN SEVERE CIVIL AND CRIMINAL PENATLIES, AND WILL BE PROSECUTED * ++++++++
000207*TO THE MAXIMUM EXTENT POSSIBLE UNDER THE LAW.                  * ++++++++
000208*COPYRIGHT 1999 PAYSYS INTERNATIONAL, INC.  ALL RIGHTS RESERVED.* ++++++++
000209***************************************************************** ++++++++
000300******************************************************************
000400*                                                                *
000500*    ----------------MERCHANT BANKCARD SYSTEM----------------    *
000600*                                                                *
000700*           MML2AB - MML2 FILE COMMON BATCH I/O ROUTINE          *
000800*                                                                *
000900*                    VARIABLE LENGTH VSAM FILE                   *
001000*                                                                *
001100*    ---------------------LOG FILE 2----------------------       *
001200*                                                                *
001300******************************************************************
001400*                                                                *
001500*    COPYBOOKS WHICH MUST APPEAR IN YOUR BATCH PROGRAM:          *
001600*                                                                *
001700*    (WS) MB00RB - BATCH REQUEST BLOCK                           *
001800*    (WS) MML1IO - I/O AREA                                      *
001900*    (WS) SS02WS - STANDARD ABEND ROUTINE WORK AREA              *
002000*    (PD) MB00PD - PROCEDURE DIVISION CALL STATEMENT             *
002100*                                                                *
002200******************************************************************
002300*                                                                *
002400*    TO USE THIS ROUTINE.........                                *
002500*                                                                *
002600* 1. HOUSEKEEPING DUTIES:                                        *
002700*                                                                *
002800*    A. IN THE HOUSEKEEPING SECTION OF YOUR PROGRAM, MOVE THE    *
002900*       NAME OF THE PROGRAM USING THIS ROUTINE TO THE FIELD      *
003000*       'SS02WS-ABEND-PROG-ID'. THIS FIELD IS USED AS PART OF THE*
003100*       STANDARD ABEND MESSAGES IF A PROGRAM ABORTS WITHIN THIS  *
003200*       ACCESS ROUTINE.  IF THE FIELD 'SS02WS-ABEND-PROG-ID' IS  *
003300*       LEFT BLANK, THIS ROUTINE WILL FORCE AN ABEND SITUATION.  *
003400*                                                                *
003500*    B. BEFORE PERFORMING THE ACCESS ROUTINE, MOVE A LITERAL TO  *
003600*       THE FIELD 'SS02WS-ABEND-LOCATION'. THIS FIELD CAN BE USED*
003700*       TO INDICATE WHERE THE ROUTINE IS BEING 'FROM' IN CASE    *
003800*       OF ABNORMAL TERMINATION. (E.G. DEBUGGING ASSISTANCE)     *
003900*                                                                *
004000*    C. SET THE RETURN CODES WHICH YOU WANT, FOR THE DURATION    *
004100*       OF THIS PROGRAM, TO BE CONSIDERED VALID IN THE FIELDS    *
004200*       'MML2RB-PERM-STATUS-1 TO -5'. THESE FIELDS ARE INITIAL-  *
004300*       IZED TO ZERO (AS ZERO IS ALWAYS AN ACCEPTABLE RETURN     *
004400*       CODE).  THIS ROUTINE WILL (IN ALL I-O REQUESTS) SUCCESS- *
004500*       FULLY SATISFY YOUR PERFORM REQUEST IF ANY OF THE REQUESTS*
004600*       ENCOUNTER ANY OF THE PERMANENT STATUS CODES 1-5.         *
004700*                                                                *
004800* 2. SET ONE OF THE FOLLOWING CONDITION NAMES TO 'TRUE' TO SET   *
004900*    THE FILE REQUEST:                                           *
005000*                                                                *
005100*        CONDITION NAME                EXPLANATION               *
005200*   *----------------------***---------------------------------* *
005300*                                                                *
005400*    MML2RB-OPEN-INPUT      - OPEN THE FILE AS INPUT WITH        *
005500*                             SEQUENTIAL ACCESS.                 *
005600*    MML2RB-OPEN-OUTPUT     - OPEN THE FILE AS OUTPUT WITH       *
005700*                             SEQUENTIAL ACCESS.                 *
005800*    MML2RB-OPEN-IO         - OPEN THE FILE AS I-O WITH          *
005900*                             SEQUENTIAL ACCESS.                 *
006000*    MML2RB-OPEN-INPUT-DYN  - OPEN THE FILE AS INPUT WITH        *
006100*                             DYNAMIC ACCESS.                    *
006200*    MML2RB-OPEN-OUTPUT-DYN - OPEN THE FILE AS OUTPUT WITH       *
006300*                             DYNAMIC ACCESS.                    *
006400*    MML2RB-OPEN-IO-DYN     - OPEN THE FILE AS I-O WITH          *
006500*                             DYNAMIC ACCESS.                    *
006600*    MML2RB-OPEN-INPUT-RDM  - OPEN THE FILE AS INPUT WITH        *
006700*                             RANDOM ACCESS.                     *
006800*    MML2RB-OPEN-OUTPUT-RDM - OPEN THE FILE AS OUTPUT WITH       *
006900*                             RANDOM ACCESS.                     *
007000*    MML2RB-OPEN-IO-RDM     - OPEN THE FILE AS I-O WITH          *
007100*                             RANDOM ACCESS.                     *
007200*    MML2RB-START-GTE       - START THE FILE WIOTH A KEY         *
007300*                             > OR            = THE        KEY   *
007400*                             CONTAINED IN 'MML2IO-KEY'.         *
007500*    MML2RB-START-EQUAL     - START THE FILE WITH A KEY =        *
007600*                             TO THE KEY CONTAINED IN            *
007700*                             'MML2IO-KEY'.                      *
007800*    MML2RB-READ-SEQ        - READ THE NEXT SEQUENTIAL RECORD    *
007900*                             IN THE FILE.                       *
008000*    MML2RB-READ-RANDOM     - READ THE RECORD IN THE FILE        *
008100*                             CORRESPONDING TO THE KEY CONTAINED *
008200*                             IN 'MML2IO-KEY'.                   *
008300*    MML2RB-WRITE           - WRITE A RECORD (THE RECORD MUST    *
008400*                             BE IN 'MML2IO-RECORD').            *
008500*    MML2RB-REWRITE         - REWRITE A RECORD (THE RECORD MUST  *
008600*                             BE IN 'MML2IO-RECORD').            *
008700*    MML2RB-DELETE          - DELETE THE RECORD IN THE FILE      *
008800*                             CORRESPONDING TO THE KEY CONTAINED *
008900*                             IN 'MML2IO-KEY'.                   *
009000*    MML2RB-CLOSE           - CLOSE THE FILE.                    *
009100*                                                                *
009200* 3. SET ONE OR BOTH OF THE 'TEMPORARY' RETURN CODE FIELDS       *
009300*    'MML2RB-TEMP-STATUS-1 AND -2'.  THESE TWO RETURN CODES      *
009400*    ARE TO BE USED ON A PER USE BASIS OF THIS ROUTINE.          *
009500*    THESE TWO RETURN CODES ARE INITIALIZED TO ZERO AND ARE      *
009600*    BOTH RESET TO ZERO AFTER EACH CALL OF THIS PROGRAM.         *
009700*    THE TEMPORARY RETURN CODE FIELDS ARE CHECKED FIRST AND      *
009800*    THEN THE PERMANENT RETURN CODES (POINT 1.C ABOVE) WILL      *
009900*    BE CHECKED.                                                 *
010000*                                                                *
010100* 4. PERFORM MB00PD-MML2-ACCESS THRU MB00PD-MML2-ACCESS-EXIT.    *
010200*                                                                *
010300*    A. YOU MUST HANDLE MANUALLY ANY RETURN CODE (EITHER TEMP    *
010400*       OR PERM) THAT YOU REQUESTED, AND IF NEEDED, YOUR OWN     *
010500*       ABEND REQUEST.                                           *
010600*                                                                *
010700*    B. ALL ACCESS ROUTINES MOVE THE FILE STATUS TO THE FIELD    *
010800*       SS02WS-FILE-STATUS IN COPYBOOK SS02WS. USE THE '88' LEVEL*
010900*       NAMES TO TEST YOUR MANUAL STATUS CHECKS.  ALSO IN COPY   *
011000*       BOOK SS02WS, USE THE 'WS-' FILE STATUS DATA NAMES WHEN   *
011100*       SETTING THE PERM OR TEMP FILE STATUS CODES PRIOR TO      *
011200*       PERFORMING THE ACCESS ROUTINE.  FOR VSAM FILES, THE VSAM *
011300*       RETURN CODE IS MOVED TO THE FIELD 'SS02WS-FILE-RETURN' IN*
011400*       COPYBOOK SS02WS.                                         *
011500*                                                                *
011600******************************************************************
011700/
011800 ENVIRONMENT DIVISION.
011900*
012000 CONFIGURATION SECTION.
012100 SOURCE-COMPUTER.            IBM-4341.
012200 OBJECT-COMPUTER.            IBM-4341.
012300*
012400 INPUT-OUTPUT SECTION.
012500*
012600 FILE-CONTROL.
012700*
012800     SELECT  MML2-FILE-SEQ
012900             ASSIGN TO MML2
013000             ORGANIZATION IS INDEXED
013100             ACCESS       IS SEQUENTIAL
013200             FILE STATUS  IS WS-STATUS
013300                             WS-RETURN
013400             RECORD KEY   IS MML2-SEQ-KEY.
013500*
013600     SELECT  MML2-FILE-DYN
013700             ASSIGN TO MML2
013800             ORGANIZATION IS INDEXED
013900             ACCESS       IS DYNAMIC
014000             FILE STATUS  IS WS-STATUS
014100                             WS-RETURN
014200             RECORD KEY   IS MML2-DYN-KEY.
014300*
014400     SELECT  MML2-FILE-RDM
014500             ASSIGN TO MML2
014600             ORGANIZATION IS INDEXED
014700             ACCESS       IS RANDOM
014800             FILE STATUS  IS WS-STATUS
014900                             WS-RETURN
015000             RECORD KEY   IS MML2-RDM-KEY.
015100*
015200 I-O-CONTROL.
015300*
015400     SAME AREA FOR
015500         MML2-FILE-SEQ
015600         MML2-FILE-DYN
015700         MML2-FILE-RDM.
015800/
015900 DATA DIVISION.
016000*
016100 FILE SECTION.
016200*
016300***********************
016400*    SEQUENTIAL FD    *
016500***********************
016600*
016700 FD  MML2-FILE-SEQ
016800     RECORD CONTAINS 74 TO 16374 CHARACTERS.
016900*
017000 01  MML2-SEQ-RECORD.
017100     03  MML2-SEQ-KEY        PIC  X(14).
017200     03  FILLER              PIC  X(60).
017300     03  MML2-SEQ-DATA       PIC  X(01)      OCCURS
017400                                             0 TO 16300 TIMES
017500                                             DEPENDING ON
017600                                             WS-DATA-LENGTH.
017700*
017800********************
017900*    DYNAMIC FD    *
018000********************
018100*
018200 FD  MML2-FILE-DYN
018300     RECORD CONTAINS 74 TO 16374 CHARACTERS.
018400*
018500 01  MML2-DYN-RECORD.
018600     03  MML2-DYN-KEY        PIC  X(14).
018700     03  FILLER              PIC  X(60).
018800     03  MML2-DYN-DATA       PIC  X(01)      OCCURS
018900                                             0 TO 16300 TIMES
019000                                             DEPENDING ON
019100                                             WS-DATA-LENGTH.
019200*
019300*******************
019400*    RANDOM FD    *
019500*******************
019600*
019700 FD  MML2-FILE-RDM
019800     RECORD CONTAINS 74 TO 16374 CHARACTERS.
019900*
020000 01  MML2-RDM-RECORD.
020100     03  MML2-RDM-KEY        PIC  X(14).
020200     03  FILLER              PIC  X(60).
020300     03  MML2-RDM-DATA       PIC  X(01)      OCCURS
020400                                             0 TO 16300 TIMES
020500                                             DEPENDING ON
020600                                             WS-DATA-LENGTH.
020700/
020800 WORKING-STORAGE SECTION.
020900*
021000 01  FILLER                  PIC  X(12)      VALUE '** WS-BEG **'.
021100*
021200 01  FILLER                  PIC  X(24)      VALUE
021300     'ACCESS METHOD INDICATOR:'.
021400*
021500 01  WS-ACCESS-METHOD        PIC  X(01)      VALUE SPACE.
021600     88  ACCESS-METHOD-NOT-SET               VALUE SPACE.
021700     88  ACCESS-IS-SEQUENTIAL                VALUE 'S'.
021800     88  ACCESS-IS-DYNAMIC                   VALUE 'D'.
021900     88  ACCESS-IS-RANDOM                    VALUE 'R'.
022000*
022100 01  FILLER                  PIC  X(12)      VALUE
022200     'FILE STATUS:'.
022300*
022400 01  WS-STATUS               PIC  X(02)      VALUE ZERO.
022500*
022600 01  FILLER                  PIC  X(16)      VALUE
022700     'EXTENDED RETURN:'.
022800*
022900 01  WS-RETURN.
023000     03  WS-RETURN-CODE      PIC 9(02)       BINARY
023100                                             VALUE ZERO.
023200     03  WS-FUNCTION-CODE    PIC 9(02)       BINARY
023300                                             VALUE ZERO.
023400     03  WS-FEEDBACK-CODE    PIC 9(02)       BINARY
023500                                             VALUE ZERO.
023600*
023700 01  FILLER                  PIC  X(12)      VALUE
023800     'I-O REQUEST:'.
023900*
024000 01  WS-IO-REQUEST           PIC  9(02)      VALUE ZERO.
024100*
024200 01  FILLER                  PIC  X(12)      VALUE
024300     'DATA LENGTH:'.
024400*
024500 01  WS-DATA-LENGTH          PIC S9(08)      BINARY
024600                                             VALUE ZERO.
024700     88  WS-MAXIMUM-DATA-LENGTH              VALUE +16300.
024800*
024900 01  FILLER                  PIC  X(28)      VALUE
025000     'PROCESSING SUMMARY COUNTERS:'.
025100*
025200 01  WS-SUMMARY-COUNTERS.
025300     03  WS-SC-READS         PIC S9(09)      PACKED-DECIMAL
025400                                             VALUE ZERO.
025500     03  WS-SC-WRITES        PIC S9(09)      PACKED-DECIMAL
025600                                             VALUE ZERO.
025700     03  WS-SC-REWRITES      PIC S9(09)      PACKED-DECIMAL
025800                                             VALUE ZERO.
025900     03  WS-SC-DELETES       PIC S9(09)      PACKED-DECIMAL
026000                                             VALUE ZERO.
026100*
026200 01  FILLER                  PIC  X(27)      VALUE
026300     'PROCESSING SUMMARY MESSAGE:'.
026400*
026500 01  WS-SUMMARY-MESSAGE.
026600     03  FILLER              PIC  X(10)      VALUE '(PGMSTAT) '.
026700     03  WS-SM-PROG-ID       PIC  X(06)      VALUE SPACES.
026800     03  FILLER              PIC  X(03)      VALUE ' - '.
026900     03  WS-SM-FILE-ID       PIC  X(04)      VALUE 'MML2'.
027000     03  FILLER              PIC  X(11)      VALUE ' - OPENED: '.
027100     03  WS-SM-ACCESS        PIC  X(03)      VALUE SPACES.
027200     03  FILLER              PIC  X(01)      VALUE SPACE.
027300     03  WS-SM-OPENED        PIC  X(06)      VALUE SPACES.
027400     03  FILLER              PIC  X(01)      VALUE SPACE.
027500     03  WS-SM-READS         PIC  ZZZZZZZZ9.
027600     03  FILLER              PIC  X(08)      VALUE ' READS, '.
027700     03  WS-SM-WRITES        PIC  ZZZZZZZZ9.
027800     03  FILLER              PIC  X(09)      VALUE ' WRITES, '.
027900     03  WS-SM-REWRITES      PIC  ZZZZZZZZ9.
028000     03  FILLER              PIC  X(11)      VALUE ' REWRITES, '.
028100     03  WS-SM-DELETES       PIC  ZZZZZZZZ9.
028200     03  FILLER              PIC  X(08)      VALUE ' DELETES'.
028300*
028400     COPY SS00WS.
028500*
028600 01  FILLER                  PIC  X(12)      VALUE '** WS-END **'.
028700/
028800 LINKAGE SECTION.
028900*
029000****************************
029100*    FILE REQUEST BLOCK    *
029200****************************
029300*
029400     COPY MB00RB REPLACING ==:MB00:== BY ==MML2==.
029500*
029600******************
029700*    I/O AREA    *
029800******************
029900*
030000     COPY MML1IO REPLACING ==:MML1:== BY ==MML2==.
030100*
030200*********************************
030300*    ABEND ROUTINE WORK AREA    *
030400*********************************
030500*
030600     COPY SS02WS.
030700/
030800 PROCEDURE DIVISION          USING MML2RB-WORK-AREA,
030900                                   MML2IO-RECORD,
031000                                   SS02WS-ABEND-WORK-AREA.
031100*
031200 A000-MAIN-LINE-SECTION.
031300*
031400*
031500***************************************************
031600*    SET THE ACCESS METHOD AND ABEND WORK AREA    *
031700*    IF THIS IS THE FIRST CALL OF THIS PROGRAM    *
031800***************************************************
031900*
032000     IF  ACCESS-METHOD-NOT-SET
032100         PERFORM Z000-PROGRAM-INITIALIZATION
032200            THRU Z099-PI-EXIT.
032300*
032400**************************************************************
032500*    PROCESS THE FILE DEPENDING OF THE PROCESSING OPTION.    *
032600**************************************************************
032700*
032800     IF  ACCESS-IS-SEQUENTIAL
032900         PERFORM S000-SEQUENTIAL-ACCESS
033000            THRU S999-SA-EXIT
033100     ELSE
033200         IF  ACCESS-IS-DYNAMIC
033300             PERFORM D000-DYNAMIC-ACCESS
033400                THRU D999-DA-EXIT
033500         ELSE
033600             PERFORM R000-RANDOM-ACCESS
033700                THRU R999-RA-EXIT.
033800*
033900*****************************************************
034000*    MOVE THE STATUS CODE AND RETURN CODE TO        *
034100*    THEIR RESPECTIVE FIELDS IN COPYBOOK SS02WS.    *
034200*****************************************************
034300*
034400     MOVE MML2RB-STATUS          TO SS02WS-FILE-STATUS.
034500     MOVE MML2RB-RETURN          TO SS02WS-FILE-RETURN.
034600*
034700 A999-GOBACK.
034800*
034900     GOBACK.
035000/
035100 D000-DYNAMIC-ACCESS.
035200*
035300     GO TO D100-DA-INVALID-REQUEST
035400           D100-DA-INVALID-REQUEST
035500           D100-DA-INVALID-REQUEST
035600           D110-DA-OPEN-INPUT
035700           D120-DA-OPEN-OUTPUT
035800           D130-DA-OPEN-I-O
035900           D100-DA-INVALID-REQUEST
036000           D100-DA-INVALID-REQUEST
036100           D100-DA-INVALID-REQUEST
036200           D140-DA-START-GTE
036300           D150-DA-START-EQUAL
036400           D160-DA-READ-SEQ
036500           D170-DA-READ-RANDOM
036600           D180-DA-WRITE
036700           D190-DA-REWRITE
036800           D200-DA-DELETE
036900           D210-DA-CLOSE
037000           DEPENDING ON MML2RB-IO-REQUEST.
037100*
037200 D100-DA-INVALID-REQUEST.
037300*
037400     MOVE MML2RB-IO-REQUEST      TO SS02WS-ABEND-REQUEST.
037500     MOVE '- BAD I-O REQ - MML2' TO SS02WS-ABENDMSG8.
037600     GO TO Z950-ABORT.
037700*
037800 D110-DA-OPEN-INPUT.
037900*
038000     OPEN INPUT MML2-FILE-DYN.
038100*
038200     IF  WS-STATUS IS EQUAL TO '97'
038300         MOVE '97'               TO MML2RB-OPEN-STATUS
038400         MOVE LOW-VALUES         TO WS-RETURN
038500         MOVE ZEROS              TO WS-STATUS.
038600*
038700     MOVE 'DYN'                  TO WS-SM-ACCESS.
038800     MOVE 'INPUT'                TO WS-SM-OPENED.
038900     MOVE '- OPEN  ERROR - MML2' TO SS02WS-ABENDMSG8.
039000     GO TO D900-DA-CHECK-STATUS.
039100*
039200 D120-DA-OPEN-OUTPUT.
039300*
039400     OPEN OUTPUT MML2-FILE-DYN.
039500*
039600     IF  WS-STATUS IS EQUAL TO '97'
039700         MOVE '97'               TO MML2RB-OPEN-STATUS
039800         MOVE LOW-VALUES         TO WS-RETURN
039900         MOVE ZEROS              TO WS-STATUS.
040000*
040100     MOVE 'DYN'                  TO WS-SM-ACCESS.
040200     MOVE 'OUTPUT'               TO WS-SM-OPENED.
040300     MOVE '- OPEN  ERROR - MML2' TO SS02WS-ABENDMSG8.
040400     GO TO D900-DA-CHECK-STATUS.
040500*
040600 D130-DA-OPEN-I-O.
040700*
040800     OPEN I-O MML2-FILE-DYN.
040900*
041000     MOVE 'DYN'                  TO WS-SM-ACCESS.
041100     MOVE 'I-O'                  TO WS-SM-OPENED.
041200     MOVE '- OPEN  ERROR - MML2' TO SS02WS-ABENDMSG8.
041300     GO TO D900-DA-CHECK-STATUS.
041400*
041500 D140-DA-START-GTE.
041600*
041700     MOVE MML2IO-KEY             TO MML2-DYN-KEY.
041800     START MML2-FILE-DYN
041900           KEY IS NOT LESS THAN MML2-DYN-KEY.
042000*
042100     MOVE '- START ERROR - MML2' TO SS02WS-ABENDMSG8.
042200     GO TO D900-DA-CHECK-STATUS.
042300*
042400 D150-DA-START-EQUAL.
042500*
042600     MOVE MML2IO-KEY             TO MML2-DYN-KEY.
042700     START MML2-FILE-DYN
042800           KEY IS EQUAL TO MML2-DYN-KEY.
042900*
043000     MOVE '- START ERROR - MML2' TO SS02WS-ABENDMSG8.
043100     GO TO D900-DA-CHECK-STATUS.
043200*
043300 D160-DA-READ-SEQ.
043400*
043500     SET WS-MAXIMUM-DATA-LENGTH  TO TRUE.
043600     READ MML2-FILE-DYN NEXT RECORD
043700                                 INTO MML2IO-RECORD.
043800*
043900     ADD 1                       TO WS-SC-READS.
044000     MOVE '- READ  ERROR - MML2' TO SS02WS-ABENDMSG8.
044100     GO TO D900-DA-CHECK-STATUS.
044200*
044300 D170-DA-READ-RANDOM.
044400*
044500     SET WS-MAXIMUM-DATA-LENGTH  TO TRUE.
044600     MOVE MML2IO-KEY             TO MML2-DYN-KEY.
044700     READ MML2-FILE-DYN          INTO MML2IO-RECORD.
044800*
044900     ADD 1                       TO WS-SC-READS.
045000     MOVE '- READ  ERROR - MML2' TO SS02WS-ABENDMSG8.
045100     GO TO D900-DA-CHECK-STATUS.
045200*
045300 D180-DA-WRITE.
045400*
045500     MOVE MML2IO-VARIABLE-LENGTH
045600                                 TO WS-DATA-LENGTH.
045700*
045800     WRITE MML2-DYN-RECORD       FROM MML2IO-RECORD.
045900*
046000     ADD 1                       TO WS-SC-WRITES.
046100     MOVE '- WRITE ERROR - MML2' TO SS02WS-ABENDMSG8.
046200     GO TO D900-DA-CHECK-STATUS.
046300*
046400 D190-DA-REWRITE.
046500*
046600     MOVE MML2IO-VARIABLE-LENGTH
046700                                 TO WS-DATA-LENGTH.
046800*
046900     REWRITE MML2-DYN-RECORD     FROM MML2IO-RECORD.
047000*
047100     ADD 1                       TO WS-SC-REWRITES.
047200     MOVE '- REWRT ERROR - MML2' TO SS02WS-ABENDMSG8.
047300     GO TO D900-DA-CHECK-STATUS.
047400*
047500 D200-DA-DELETE.
047600*
047700     MOVE MML2IO-KEY             TO MML2-DYN-KEY.
047800     DELETE MML2-FILE-DYN RECORD.
047900*
048000     ADD 1                       TO WS-SC-DELETES.
048100     MOVE '- DELET ERROR - MML2' TO SS02WS-ABENDMSG8.
048200     GO TO D900-DA-CHECK-STATUS.
048300*
048400 D210-DA-CLOSE.
048500*
048600     MOVE SPACE                  TO WS-ACCESS-METHOD.
048700     CLOSE  MML2-FILE-DYN.
048800*
048900     PERFORM Z100-DISPLAY-THE-SUMMARY
049000        THRU Z199-DTS-EXIT.
049100*
049200     MOVE '- CLOSE ERROR - MML2' TO SS02WS-ABENDMSG8.
049300     GO TO D900-DA-CHECK-STATUS.
049400*
049500 D900-DA-CHECK-STATUS.
049600*
049700     MOVE WS-STATUS              TO MML2RB-STATUS.
049800     MOVE WS-RETURN              TO MML2RB-RETURN.
049900*
050000     IF  MML2RB-STATUS IS EQUAL  TO MML2RB-TEMP-STATUS-1   OR
050100         MML2RB-STATUS IS EQUAL  TO MML2RB-TEMP-STATUS-2   OR
050200         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-1   OR
050300         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-2   OR
050400         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-3   OR
050500         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-4   OR
050600         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-5
050700         MOVE ZERO               TO MML2RB-TEMP-STATUS-1
050800         MOVE ZERO               TO MML2RB-TEMP-STATUS-2
050900     ELSE
051000         GO TO Z900-ABORT.
051100*
051200 D999-DA-EXIT.
051300     EXIT.
051400/
051500 R000-RANDOM-ACCESS.
051600*
051700     GO TO R100-RA-INVALID-REQUEST
051800           R100-RA-INVALID-REQUEST
051900           R100-RA-INVALID-REQUEST
052000           R100-RA-INVALID-REQUEST
052100           R100-RA-INVALID-REQUEST
052200           R100-RA-INVALID-REQUEST
052300           R110-RA-OPEN-INPUT
052400           R120-RA-OPEN-OUTPUT
052500           R130-RA-OPEN-I-O
052600           R100-RA-INVALID-REQUEST
052700           R100-RA-INVALID-REQUEST
052800           R100-RA-INVALID-REQUEST
052900           R140-RA-READ-RANDOM
053000           R150-RA-WRITE
053100           R160-RA-REWRITE
053200           R170-RA-DELETE
053300           R180-RA-CLOSE
053400           DEPENDING ON MML2RB-IO-REQUEST.
053500*
053600 R100-RA-INVALID-REQUEST.
053700*
053800     MOVE MML2RB-IO-REQUEST      TO SS02WS-ABEND-REQUEST.
053900     MOVE '- BAD I-O REQ - MML2' TO SS02WS-ABENDMSG8.
054000     GO TO Z950-ABORT.
054100*
054200 R110-RA-OPEN-INPUT.
054300*
054400     OPEN INPUT MML2-FILE-RDM.
054500*
054600     IF  WS-STATUS IS EQUAL TO '97'
054700         MOVE '97'               TO MML2RB-OPEN-STATUS
054800         MOVE LOW-VALUES         TO WS-RETURN
054900         MOVE ZEROS              TO WS-STATUS.
055000*
055100     MOVE 'RDM'                  TO WS-SM-ACCESS.
055200     MOVE 'INPUT'                TO WS-SM-OPENED.
055300     MOVE '- OPEN  ERROR - MML2' TO SS02WS-ABENDMSG8.
055400     GO TO R900-RA-CHECK-STATUS.
055500*
055600 R120-RA-OPEN-OUTPUT.
055700*
055800     OPEN OUTPUT MML2-FILE-RDM.
055900*
056000     IF  WS-STATUS IS EQUAL TO '97'
056100         MOVE '97'               TO MML2RB-OPEN-STATUS
056200         MOVE LOW-VALUES         TO WS-RETURN
056300         MOVE ZEROS              TO WS-STATUS.
056400*
056500     MOVE 'RDM'                  TO WS-SM-ACCESS.
056600     MOVE 'OUTPUT'               TO WS-SM-OPENED.
056700     MOVE '- OPEN  ERROR - MML2' TO SS02WS-ABENDMSG8.
056800     GO TO R900-RA-CHECK-STATUS.
056900*
057000 R130-RA-OPEN-I-O.
057100*
057200     OPEN I-O MML2-FILE-RDM.
057300*
057400     MOVE 'RDM'                  TO WS-SM-ACCESS.
057500     MOVE 'I-O'                  TO WS-SM-OPENED.
057600     MOVE '- OPEN  ERROR - MML2' TO SS02WS-ABENDMSG8.
057700     GO TO R900-RA-CHECK-STATUS.
057800*
057900 R140-RA-READ-RANDOM.
058000*
058100     SET WS-MAXIMUM-DATA-LENGTH  TO TRUE.
058200     MOVE MML2IO-KEY             TO MML2-RDM-KEY.
058300     READ MML2-FILE-RDM          INTO MML2IO-RECORD.
058400*
058500     ADD 1                       TO WS-SC-READS.
058600     MOVE '- READ  ERROR - MML2' TO SS02WS-ABENDMSG8.
058700     GO TO R900-RA-CHECK-STATUS.
058800*
058900 R150-RA-WRITE.
059000*
059100     MOVE MML2IO-VARIABLE-LENGTH
059200                                 TO WS-DATA-LENGTH.
059300*
059400     WRITE MML2-RDM-RECORD       FROM MML2IO-RECORD.
059500*
059600     ADD 1                       TO WS-SC-WRITES.
059700     MOVE '- WRITE ERROR - MML2' TO SS02WS-ABENDMSG8.
059800     GO TO R900-RA-CHECK-STATUS.
059900*
060000 R160-RA-REWRITE.
060100*
060200     MOVE MML2IO-VARIABLE-LENGTH
060300                                 TO WS-DATA-LENGTH.
060400*
060500     REWRITE MML2-RDM-RECORD     FROM MML2IO-RECORD.
060600*
060700     ADD 1                       TO WS-SC-REWRITES.
060800     MOVE '- REWRT ERROR - MML2' TO SS02WS-ABENDMSG8.
060900     GO TO R900-RA-CHECK-STATUS.
061000*
061100 R170-RA-DELETE.
061200*
061300     MOVE MML2IO-KEY             TO MML2-RDM-KEY.
061400     DELETE MML2-FILE-RDM RECORD.
061500*
061600     ADD 1                       TO WS-SC-DELETES.
061700     MOVE '- DELET ERROR - MML2' TO SS02WS-ABENDMSG8.
061800     GO TO R900-RA-CHECK-STATUS.
061900*
062000 R180-RA-CLOSE.
062100*
062200     MOVE SPACE                  TO WS-ACCESS-METHOD.
062300     CLOSE  MML2-FILE-RDM.
062400*
062500     PERFORM Z100-DISPLAY-THE-SUMMARY
062600        THRU Z199-DTS-EXIT.
062700*
062800     MOVE '- CLOSE ERROR - MML2' TO SS02WS-ABENDMSG8.
062900     GO TO R900-RA-CHECK-STATUS.
063000*
063100 R900-RA-CHECK-STATUS.
063200*
063300     MOVE WS-STATUS              TO MML2RB-STATUS.
063400     MOVE WS-RETURN              TO MML2RB-RETURN.
063500*
063600     IF  MML2RB-STATUS IS EQUAL  TO MML2RB-TEMP-STATUS-1   OR
063700         MML2RB-STATUS IS EQUAL  TO MML2RB-TEMP-STATUS-2   OR
063800         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-1   OR
063900         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-2   OR
064000         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-3   OR
064100         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-4   OR
064200         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-5
064300         MOVE ZERO               TO MML2RB-TEMP-STATUS-1
064400         MOVE ZERO               TO MML2RB-TEMP-STATUS-2
064500     ELSE
064600         GO TO Z900-ABORT.
064700*
064800 R999-RA-EXIT.
064900     EXIT.
065000/
065100 S000-SEQUENTIAL-ACCESS.
065200*
065300     GO TO S110-SA-OPEN-INPUT
065400           S120-SA-OPEN-OUTPUT
065500           S130-SA-OPEN-I-O
065600           S100-SA-INVALID-REQUEST
065700           S100-SA-INVALID-REQUEST
065800           S100-SA-INVALID-REQUEST
065900           S100-SA-INVALID-REQUEST
066000           S100-SA-INVALID-REQUEST
066100           S100-SA-INVALID-REQUEST
066200           S140-SA-START-GTE
066300           S150-SA-START-EQUAL
066400           S160-SA-READ-SEQ
066500           S100-SA-INVALID-REQUEST
066600           S170-SA-WRITE
066700           S180-SA-REWRITE
066800           S190-SA-DELETE
066900           S200-SA-CLOSE
067000           DEPENDING ON MML2RB-IO-REQUEST.
067100*
067200 S100-SA-INVALID-REQUEST.
067300*
067400     MOVE MML2RB-IO-REQUEST      TO SS02WS-ABEND-REQUEST.
067500     MOVE '- BAD I-O REQ - MML2' TO SS02WS-ABENDMSG8.
067600     GO TO Z950-ABORT.
067700*
067800 S110-SA-OPEN-INPUT.
067900*
068000     OPEN INPUT MML2-FILE-SEQ.
068100*
068200     IF  WS-STATUS IS EQUAL TO '97'
068300         MOVE '97'               TO MML2RB-OPEN-STATUS
068400         MOVE LOW-VALUES         TO WS-RETURN
068500         MOVE ZEROS              TO WS-STATUS.
068600*
068700     MOVE 'SEQ'                  TO WS-SM-ACCESS.
068800     MOVE 'INPUT'                TO WS-SM-OPENED.
068900     MOVE '- OPEN  ERROR - MML2' TO SS02WS-ABENDMSG8.
069000     GO TO S900-SA-CHECK-STATUS.
069100*
069200 S120-SA-OPEN-OUTPUT.
069300*
069400     OPEN OUTPUT MML2-FILE-SEQ.
069500*
069600     IF  WS-STATUS IS EQUAL TO '97'
069700         MOVE '97'               TO MML2RB-OPEN-STATUS
069800         MOVE LOW-VALUES         TO WS-RETURN
069900         MOVE ZEROS              TO WS-STATUS.
070000*
070100     MOVE 'SEQ'                  TO WS-SM-ACCESS.
070200     MOVE 'OUTPUT'               TO WS-SM-OPENED.
070300     MOVE '- OPEN  ERROR - MML2' TO SS02WS-ABENDMSG8.
070400     GO TO S900-SA-CHECK-STATUS.
070500*
070600 S130-SA-OPEN-I-O.
070700*
070800     OPEN I-O MML2-FILE-SEQ.
070900*
071000     MOVE 'SEQ'                  TO WS-SM-ACCESS.
071100     MOVE 'I-O'                  TO WS-SM-OPENED.
071200     MOVE '- OPEN  ERROR - MML2' TO SS02WS-ABENDMSG8.
071300     GO TO S900-SA-CHECK-STATUS.
071400*
071500 S140-SA-START-GTE.
071600*
071700     MOVE MML2IO-KEY             TO MML2-SEQ-KEY.
071800     START MML2-FILE-SEQ
071900           KEY IS NOT LESS THAN MML2-SEQ-KEY.
072000*
072100     MOVE '- START ERROR - MML2' TO SS02WS-ABENDMSG8.
072200     GO TO S900-SA-CHECK-STATUS.
072300*
072400 S150-SA-START-EQUAL.
072500*
072600     MOVE MML2IO-KEY             TO MML2-SEQ-KEY.
072700     START MML2-FILE-SEQ
072800           KEY IS EQUAL TO MML2-SEQ-KEY.
072900*
073000     MOVE '- START ERROR - MML2' TO SS02WS-ABENDMSG8.
073100     GO TO S900-SA-CHECK-STATUS.
073200*
073300 S160-SA-READ-SEQ.
073400*
073500     SET WS-MAXIMUM-DATA-LENGTH  TO TRUE.
073600     READ MML2-FILE-SEQ          INTO MML2IO-RECORD.
073700*
073800     ADD 1                       TO WS-SC-READS.
073900     MOVE '- READ  ERROR - MML2' TO SS02WS-ABENDMSG8.
074000     GO TO S900-SA-CHECK-STATUS.
074100*
074200 S170-SA-WRITE.
074300*
074400     MOVE MML2IO-VARIABLE-LENGTH
074500                                 TO WS-DATA-LENGTH.
074600*
074700     WRITE MML2-SEQ-RECORD       FROM MML2IO-RECORD.
074800*
074900     ADD 1                       TO WS-SC-WRITES.
075000     MOVE '- WRITE ERROR - MML2' TO SS02WS-ABENDMSG8.
075100     GO TO S900-SA-CHECK-STATUS.
075200*
075300 S180-SA-REWRITE.
075400*
075500     MOVE MML2IO-VARIABLE-LENGTH
075600                                 TO WS-DATA-LENGTH.
075700*
075800     REWRITE MML2-SEQ-RECORD     FROM MML2IO-RECORD.
075900*
076000     ADD 1                       TO WS-SC-REWRITES.
076100     MOVE '- REWRT ERROR - MML2' TO SS02WS-ABENDMSG8.
076200     GO TO S900-SA-CHECK-STATUS.
076300*
076400 S190-SA-DELETE.
076500*
076600     MOVE MML2IO-KEY             TO MML2-SEQ-KEY.
076700     DELETE MML2-FILE-SEQ RECORD.
076800*
076900     ADD 1                       TO WS-SC-DELETES.
077000     MOVE '- DELET ERROR - MML2' TO SS02WS-ABENDMSG8.
077100     GO TO S900-SA-CHECK-STATUS.
077200*
077300 S200-SA-CLOSE.
077400*
077500     MOVE SPACE                  TO WS-ACCESS-METHOD.
077600     CLOSE MML2-FILE-SEQ.
077700*
077800     PERFORM Z100-DISPLAY-THE-SUMMARY
077900        THRU Z199-DTS-EXIT.
078000*
078100     MOVE '- CLOSE ERROR - MML2' TO SS02WS-ABENDMSG8.
078200     GO TO S900-SA-CHECK-STATUS.
078300*
078400 S900-SA-CHECK-STATUS.
078500*
078600     MOVE WS-STATUS              TO MML2RB-STATUS.
078700     MOVE WS-RETURN              TO MML2RB-RETURN.
078800*
078900     IF  MML2RB-STATUS IS EQUAL  TO MML2RB-TEMP-STATUS-1   OR
079000         MML2RB-STATUS IS EQUAL  TO MML2RB-TEMP-STATUS-2   OR
079100         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-1   OR
079200         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-2   OR
079300         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-3   OR
079400         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-4   OR
079500         MML2RB-STATUS IS EQUAL  TO MML2RB-PERM-STATUS-5
079600         MOVE ZERO               TO MML2RB-TEMP-STATUS-1
079700         MOVE ZERO               TO MML2RB-TEMP-STATUS-2
079800     ELSE
079900         GO TO Z900-ABORT.
080000*
080100 S999-SA-EXIT.
080200     EXIT.
080300/
080400 Z000-PROGRAM-INITIALIZATION.
080500*
080600************************************************************
080700*    THE CALLING PROGRAM MUST SUPPLY THE PROGRAM ID TO     *
080800*    ENSURE THAT ANY SUBSEQUENT ABEND CAN BE TRACED TO     *
080900*    IT.  IF THE PROGRAM ID IS NOT SUPPLIED, THE ACCESS    *
081000*    ROUTINE ABENDS HERE.                                  *
081100************************************************************
081200*
081300     IF  SS02WS-ABEND-PROG-ID IS EQUAL TO SPACES
081400         MOVE '- BAD PROG NAME - MML2'
081500                                 TO SS02WS-ABENDMSG8
081600         MOVE 'BADPRO'           TO SS02WS-ABEND-PROG-ID
081700         GO TO Z950-ABORT.
081800*
081900     MOVE SS02WS-ABEND-PROG-ID   TO WS-SM-PROG-ID.
082000*
082100*************************************************************
082200*    SINCE THIS ROUTINE IS PERFORMED ONLY ONCE DURING       *
082300*    THE EXECUTION OF A CALLING PROGRAM, THE FIRST          *
082400*    REQUEST MUST BE FOR AN OPEN.  SET THE ACCESS METHOD    *
082500*    (SEQENTIAL, DYNAMIC, OR RANDOM), OR ISSUE AN ABEND     *
082600*    IF THE REQUEST IS NOT FOR AN OPEN.                     *
082700*************************************************************
082800*
082900     IF  MML2RB-OPEN-INPUT    OR
083000         MML2RB-OPEN-OUTPUT   OR
083100         MML2RB-OPEN-IO
083200         MOVE 'S'                TO WS-ACCESS-METHOD.
083300*
083400     IF  MML2RB-OPEN-INPUT-DYN    OR
083500         MML2RB-OPEN-OUTPUT-DYN   OR
083600         MML2RB-OPEN-IO-DYN
083700         MOVE 'D'                TO WS-ACCESS-METHOD.
083800*
083900     IF  MML2RB-OPEN-INPUT-RDM    OR
084000         MML2RB-OPEN-OUTPUT-RDM   OR
084100         MML2RB-OPEN-IO-RDM
084200         MOVE 'R'                TO WS-ACCESS-METHOD.
084300*
084400     IF  ACCESS-METHOD-NOT-SET
084500         MOVE 'SMML2'            TO SS02WS-ABEND-CODE-X
084600         MOVE MML2RB-IO-REQUEST  TO WS-IO-REQUEST
084700         MOVE WS-IO-REQUEST      TO SS02WS-ABEND-REQUEST
084800         MOVE 'ILLEGAL ACCESS REQUEST'
084900                                 TO SS02WS-ABENDMSG8
085000         GO TO Z950-ABORT.
085100*
085200 Z099-PI-EXIT.
085300     EXIT.
085400*
085500 Z100-DISPLAY-THE-SUMMARY.
085600*
085700     MOVE WS-SC-READS            TO WS-SM-READS.
085800     MOVE WS-SC-WRITES           TO WS-SM-WRITES.
085900     MOVE WS-SC-REWRITES         TO WS-SM-REWRITES.
086000     MOVE WS-SC-DELETES          TO WS-SM-DELETES.
086100     DISPLAY WS-SUMMARY-MESSAGE.
086200*
086300     INITIALIZE WS-SUMMARY-COUNTERS.
086400*
086500 Z199-DTS-EXIT.
086600     EXIT.
086700/
086800 Z900-ABORT.
086900*
087000     MOVE 'SMML2'                TO SS02WS-ABEND-CODE-X.
087100     MOVE MML2RB-STATUS          TO SS02WS-ABEND-STATUS.
087200     MOVE MML2RB-RETURN-CODE     TO SS02WS-ABEND-RETURN.
087300     MOVE MML2RB-FUNCTION-CODE   TO SS02WS-ABEND-FUNCTION.
087400     MOVE MML2RB-FEEDBACK-CODE   TO SS02WS-ABEND-FEEDBACK.
087500     MOVE MML2RB-IO-REQUEST      TO WS-IO-REQUEST.
087600     MOVE WS-IO-REQUEST          TO SS02WS-ABEND-REQUEST.
087700*
087800 Z950-ABORT.
087900*
088000     PERFORM SS02PD-ABEND        THRU SS02PD-ABEND-EXIT.
088100*
088200 Z999-ABORT-EXIT.
088300     EXIT.
088400/
088500********************************
088600*    STANDARD ABEND ROUTINE    *
088700********************************
088800*
088900     COPY SS02PD.
089000*
