000100 IDENTIFICATION DIVISION.
000200 PROGRAM-ID. MTRDAB.
000201*       RELEASE DATE=08/24/01.        REVISION LEVEL=08.06      * ++++++++
000202***************************************************************** ++++++++
000203*WARNING.  THIS COMPUTER PROGRAM IS PROTECTED BY COPYRIGHT LAW  * ++++++++
000204*AND INTERNATIONAL TREATIES.  UNAUTHORIZED REPRODUCTION OR      * ++++++++
000205*DISTRIBUTION OF THIS PROGRAM, OR ANY PORTION OF IT, MAY RESULT * ++++++++
000206*IN SEVERE CIVIL AND CRIMINAL PENATLIES, AND WILL BE PROSECUTED * ++++++++
000207*TO THE MAXIMUM EXTENT POSSIBLE UNDER THE LAW.                  * ++++++++
000208*COPYRIGHT 1999 PAYSYS INTERNATIONAL, INC.  ALL RIGHTS RESERVED.* ++++++++
000209***************************************************************** ++++++++
000300******************************************************************
000400*                                                                *
000500*    ---------------MERCHANT BANKCARD SYSTEM---------------      *
000600*                                                                *
000700*          MTRDAB - MTRD FILE COMMON BATCH I/O ROUTINE           *
000800*                                                                *
000900*                    FIXED LENGTH VSAM FILE                      *
001000*                                                                *
001100*    ----------MERCHANT RELATIONSHIP DETAIL FILE ----------      *
001200*                                                                *
001300******************************************************************
001400*                                                                *
001500*    COPYBOOKS WHICH MUST APPEAR IN YOUR BATCH PROGRAM:          *
001600*                                                                *
001700*    (WS) MB00RB - BATCH REQUEST BLOCK                           *
001800*    (WS) MMRDIO - I/O AREA                                      *
001900*    (WS) SS02WS - STANDARD ABEND ROUTINE WORK AREA              *
002000*    (PD) MB00PD - PROCEDURE DIVISION CALL STATEMENT             *
002100*                                                                *
002200******************************************************************
002300*                                                                *
002400*    TO USE THIS ROUTINE.........                                *
002500*                                                                *
002600* 1. HOUSEKEEPING DUTIES:                                        *
002700*                                                                *
002800*    A. IN THE HOUSEKEEPING SECTION OF YOUR PROGRAM, MOVE THE    *
002900*       NAME OF THE PROGRAM USING THIS ROUTINE TO THE FIELD      *
003000*       'SS02WS-ABEND-PROG-ID'. THIS FIELD IS USED AS PART OF THE*
003100*       STANDARD ABEND MESSAGES IF A PROGRAM ABORTS WITHIN THIS  *
003200*       ACCESS ROUTINE.  IF THE FIELD 'SS02WS-ABEND-PROG-ID' IS  *
003300*       LEFT BLANK, THIS ROUTINE WILL FORCE AN ABEND SITUATION.  *
003400*                                                                *
003500*    B. BEFORE PERFORMING THE ACCESS ROUTINE, MOVE A LITERAL TO  *
003600*       THE FIELD 'SS02WS-ABEND-LOCATION'. THIS FIELD CAN BE USED*
003700*       TO INDICATE WHERE THE ROUTINE IS BEING 'FROM' IN CASE    *
003800*       OF ABNORMAL TERMINATION. (E.G. DEBUGGING ASSISTANCE)     *
003900*                                                                *
004000*    C. SET THE RETURN CODES WHICH YOU WANT, FOR THE DURATION    *
004100*       OF THIS PROGRAM, TO BE CONSIDERED VALID IN THE FIELDS    *
004200*       'MTRDRB-PERM-STATUS-1 TO -5'. THESE FIELDS ARE INITIAL-  *
004300*       IZED TO ZERO (AS ZERO IS ALWAYS AN ACCEPTABLE RETURN     *
004400*       CODE).  THIS ROUTINE WILL (IN ALL I-O REQUESTS) SUCCESS- *
004500*       FULLY SATISFY YOUR PERFORM REQUEST IF ANY OF THE REQUESTS*
004600*       ENCOUNTER ANY OF THE PERMANENT STATUS CODES 1-5.         *
004700*                                                                *
004800* 2. SET ONE OF THE FOLLOWING CONDITION NAMES TO 'TRUE' TO SET   *
004900*    THE FILE REQUEST:                                           *
005000*                                                                *
005100*        CONDITION NAME                EXPLANATION               *
005200*   *----------------------***---------------------------------* *
005300*                                                                *
005400*    MTRDRB-OPEN-INPUT      - OPEN THE FILE AS INPUT WITH        *
005500*                             SEQUENTIAL ACCESS.                 *
005600*    MTRDRB-OPEN-OUTPUT     - OPEN THE FILE AS OUTPUT WITH       *
005700*                             SEQUENTIAL ACCESS.                 *
005800*    MTRDRB-OPEN-IO         - OPEN THE FILE AS I-O WITH          *
005900*                             SEQUENTIAL ACCESS.                 *
006000*    MTRDRB-OPEN-INPUT-DYN  - OPEN THE FILE AS INPUT WITH        *
006100*                             DYNAMIC ACCESS.                    *
006200*    MTRDRB-OPEN-OUTPUT-DYN - OPEN THE FILE AS OUTPUT WITH       *
006300*                             DYNAMIC ACCESS.                    *
006400*    MTRDRB-OPEN-IO-DYN     - OPEN THE FILE AS I-O WITH          *
006500*                             DYNAMIC ACCESS.                    *
006600*    MTRDRB-OPEN-INPUT-RDM  - OPEN THE FILE AS INPUT WITH        *
006700*                             RANDOM ACCESS.                     *
006800*    MTRDRB-OPEN-OUTPUT-RDM - OPEN THE FILE AS OUTPUT WITH       *
006900*                             RANDOM ACCESS.                     *
007000*    MTRDRB-OPEN-IO-RDM     - OPEN THE FILE AS I-O WITH          *
007100*                             RANDOM ACCESS.                     *
007200*    MTRDRB-START-GTE       - START THE FILE WIOTH A KEY         *
007300*                             > OR            = THE        KEY   *
007400*                             CONTAINED IN 'MTRDIO-KEY'.         *
007500*    MTRDRB-START-EQUAL     - START THE FILE WITH A KEY =        *
007600*                             TO THE KEY CONTAINED IN            *
007700*                             'MTRDIO-KEY'.                      *
007800*    MTRDRB-READ-SEQ        - READ THE NEXT SEQUENTIAL RECORD    *
007900*                             IN THE FILE.                       *
008000*    MTRDRB-READ-RANDOM     - READ THE RECORD IN THE FILE        *
008100*                             CORRESPONDING TO THE KEY CONTAINED *
008200*                             IN 'MTRDIO-KEY'.                   *
008300*    MTRDRB-WRITE           - WRITE A RECORD (THE RECORD MUST    *
008400*                             BE IN 'MTRDIO-RECORD').            *
008500*    MTRDRB-REWRITE         - REWRITE A RECORD (THE RECORD MUST  *
008600*                             BE IN 'MTRDIO-RECORD').            *
008700*    MTRDRB-DELETE          - DELETE THE RECORD IN THE FILE      *
008800*                             CORRESPONDING TO THE KEY CONTAINED *
008900*                             IN 'MTRDIO-KEY'.                   *
009000*    MTRDRB-CLOSE           - CLOSE THE FILE.                    *
009100*                                                                *
009200* 3. SET ONE OR BOTH OF THE 'TEMPORARY' RETURN CODE FIELDS       *
009300*    'MTRDRB-TEMP-STATUS-1 AND -2'.  THESE TWO RETURN CODES      *
009400*    ARE TO BE USED ON A PER USE BASIS OF THIS ROUTINE.          *
009500*    THESE TWO RETURN CODES ARE INITIALIZED TO ZERO AND ARE      *
009600*    BOTH RESET TO ZERO AFTER EACH CALL OF THIS PROGRAM.         *
009700*    THE TEMPORARY RETURN CODE FIELDS ARE CHECKED FIRST AND      *
009800*    THEN THE PERMANENT RETURN CODES (POINT 1.C ABOVE) WILL      *
009900*    BE CHECKED.                                                 *
010000*                                                                *
010100* 4. PERFORM MB00PD-MTRD-ACCESS THRU MB00PD-MTRD-ACCESS-EXIT.    *
010200*                                                                *
010300*    A. YOU MUST HANDLE MANUALLY ANY RETURN CODE (EITHER TEMP    *
010400*       OR PERM) THAT YOU REQUESTED, AND IF NEEDED, YOUR OWN     *
010500*       ABEND REQUEST.                                           *
010600*                                                                *
010700*    B. ALL ACCESS ROUTINES MOVE THE FILE STATUS TO THE FIELD    *
010800*       SS02WS-FILE-STATUS IN COPYBOOK SS02WS. USE THE '88' LEVEL*
010900*       NAMES TO TEST YOUR MANUAL STATUS CHECKS.  ALSO IN COPY   *
011000*       BOOK SS02WS, USE THE 'WS-' FILE STATUS DATA NAMES WHEN   *
011100*       SETTING THE PERM OR TEMP FILE STATUS CODES PRIOR TO      *
011200*       PERFORMING THE ACCESS ROUTINE.  FOR VSAM FILES, THE VSAM *
011300*       RETURN CODE IS MOVED TO THE FIELD 'SS02WS-FILE-RETURN' IN*
011400*       COPYBOOK SS02WS.                                         *
011500*                                                                *
011600******************************************************************
011700/
011800 ENVIRONMENT DIVISION.
011900*
012000 CONFIGURATION SECTION.
012100 SOURCE-COMPUTER.            IBM-4341.
012200 OBJECT-COMPUTER.            IBM-4341.
012300*
012400 INPUT-OUTPUT SECTION.
012500*
012600 FILE-CONTROL.
012700*
012800     SELECT  MTRD-FILE-SEQ
012900             ASSIGN TO MTRD
013000             ORGANIZATION IS INDEXED
013100             ACCESS       IS SEQUENTIAL
013200             FILE STATUS  IS WS-STATUS
013300                             WS-RETURN
013400             RECORD KEY   IS MTRD-SEQ-KEY.
013500*
013600     SELECT  MTRD-FILE-DYN
013700             ASSIGN TO MTRD
013800             ORGANIZATION IS INDEXED
013900             ACCESS       IS DYNAMIC
014000             FILE STATUS  IS WS-STATUS
014100                             WS-RETURN
014200             RECORD KEY   IS MTRD-DYN-KEY.
014300*
014400     SELECT  MTRD-FILE-RDM
014500             ASSIGN TO MTRD
014600             ORGANIZATION IS INDEXED
014700             ACCESS       IS RANDOM
014800             FILE STATUS  IS WS-STATUS
014900                             WS-RETURN
015000             RECORD KEY   IS MTRD-RDM-KEY.
015100*
015200 I-O-CONTROL.
015300*
015400     SAME AREA FOR
015500         MTRD-FILE-SEQ
015600         MTRD-FILE-DYN
015700         MTRD-FILE-RDM.
015800/
015900 DATA DIVISION.
016000*
016100 FILE SECTION.
016200*
016300***********************
016400*    SEQUENTIAL FD    *
016500***********************
016600*
016700 FD  MTRD-FILE-SEQ
016800     RECORD CONTAINS 4080 CHARACTERS.
016900*
017000 01  MTRD-SEQ-RECORD.
017100     03  MTRD-SEQ-KEY        PIC  X(14).
017200     03  MTRD-SEQ-DATA       PIC  X(4066).
017300*
017400********************
017500*    DYNAMIC FD    *
017600********************
017700*
017800 FD  MTRD-FILE-DYN
017900     RECORD CONTAINS 4080 CHARACTERS.
018000*
018100 01  MTRD-DYN-RECORD.
018200     03  MTRD-DYN-KEY        PIC  X(14).
018300     03  MTRD-DYN-DATA       PIC  X(4066).
018400*
018500*******************
018600*    RANDOM FD    *
018700*******************
018800*
018900 FD  MTRD-FILE-RDM
019000     RECORD CONTAINS 4080 CHARACTERS.
019100*
019200 01  MTRD-RDM-RECORD.
019300     03  MTRD-RDM-KEY        PIC  X(14).
019400     03  MTRD-RDM-DATA       PIC  X(4066).
019500/
019600 WORKING-STORAGE SECTION.
019700*
019800 01  FILLER                  PIC  X(12)      VALUE '** WS-BEG **'.
019900*
020000 01  FILLER                  PIC  X(24)      VALUE
020100     'ACCESS METHOD INDICATOR:'.
020200*
020300 01  WS-ACCESS-METHOD        PIC  X(01)      VALUE SPACE.
020400     88  ACCESS-METHOD-NOT-SET               VALUE SPACE.
020500     88  ACCESS-IS-SEQUENTIAL                VALUE 'S'.
020600     88  ACCESS-IS-DYNAMIC                   VALUE 'D'.
020700     88  ACCESS-IS-RANDOM                    VALUE 'R'.
020800*
020900 01  FILLER                  PIC  X(12)      VALUE
021000     'FILE STATUS:'.
021100*
021200 01  WS-STATUS               PIC  X(02)      VALUE ZERO.
021300*
021400 01  FILLER                  PIC  X(16)      VALUE
021500     'EXTENDED RETURN:'.
021600*
021700 01  WS-RETURN.
021800     03  WS-RETURN-CODE      PIC 9(02)       BINARY
021900                                             VALUE ZERO.
022000     03  WS-FUNCTION-CODE    PIC 9(02)       BINARY
022100                                             VALUE ZERO.
022200     03  WS-FEEDBACK-CODE    PIC 9(02)       BINARY
022300                                             VALUE ZERO.
022400*
022500 01  FILLER                  PIC  X(12)      VALUE
022600     'I-O REQUEST:'.
022700*
022800 01  WS-IO-REQUEST           PIC  9(02)      VALUE ZERO.
022900*
023000 01  FILLER                  PIC  X(28)      VALUE
023100     'PROCESSING SUMMARY COUNTERS:'.
023200*
023300 01  WS-SUMMARY-COUNTERS.
023400     03  WS-SC-READS         PIC S9(09)      PACKED-DECIMAL
023500                                             VALUE ZERO.
023600     03  WS-SC-WRITES        PIC S9(09)      PACKED-DECIMAL
023700                                             VALUE ZERO.
023800     03  WS-SC-REWRITES      PIC S9(09)      PACKED-DECIMAL
023900                                             VALUE ZERO.
024000     03  WS-SC-DELETES       PIC S9(09)      PACKED-DECIMAL
024100                                             VALUE ZERO.
024200*
024300 01  FILLER                  PIC  X(27)      VALUE
024400     'PROCESSING SUMMARY MESSAGE:'.
024500*
024600 01  WS-SUMMARY-MESSAGE.
024700     03  FILLER              PIC  X(10)      VALUE '(PGMSTAT) '.
024800     03  WS-SM-PROG-ID       PIC  X(06)      VALUE SPACES.
024900     03  FILLER              PIC  X(03)      VALUE ' - '.
025000     03  WS-SM-FILE-ID       PIC  X(04)      VALUE 'MTRD'.
025100     03  FILLER              PIC  X(11)      VALUE ' - OPENED: '.
025200     03  WS-SM-ACCESS        PIC  X(03)      VALUE SPACES.
025300     03  FILLER              PIC  X(01)      VALUE SPACE.
025400     03  WS-SM-OPENED        PIC  X(06)      VALUE SPACES.
025500     03  FILLER              PIC  X(01)      VALUE SPACE.
025600     03  WS-SM-READS         PIC  ZZZZZZZZ9.
025700     03  FILLER              PIC  X(08)      VALUE ' READS, '.
025800     03  WS-SM-WRITES        PIC  ZZZZZZZZ9.
025900     03  FILLER              PIC  X(09)      VALUE ' WRITES, '.
026000     03  WS-SM-REWRITES      PIC  ZZZZZZZZ9.
026100     03  FILLER              PIC  X(11)      VALUE ' REWRITES, '.
026200     03  WS-SM-DELETES       PIC  ZZZZZZZZ9.
026300     03  FILLER              PIC  X(08)      VALUE ' DELETES'.
026400*
026500/
026600     COPY SS00WS.
026700*
026800 01  FILLER                  PIC  X(12)      VALUE '** WS-END **'.
026900/
027000 LINKAGE SECTION.
027100*
027200****************************
027300*    FILE REQUEST BLOCK    *
027400****************************
027500*
027600     COPY MB00RB REPLACING ==:MB00:== BY ==MTRD==.
027700*
027800******************
027900*    I/O AREA    *
028000******************
028100*
028200     COPY MMRDIO REPLACING ==:MMRD:== BY ==MTRD==.
028300*
028400*********************************
028500*    ABEND ROUTINE WORK AREA    *
028600*********************************
028700*
028800     COPY SS02WS.
028900/
029000 PROCEDURE DIVISION          USING MTRDRB-WORK-AREA,
029100                                   MTRDIO-RECORD,
029200                                   SS02WS-ABEND-WORK-AREA.
029300*
029400 A000-MAIN-LINE-SECTION.
029500*
029600*
029700***************************************************
029800*    SET THE ACCESS METHOD AND ABEND WORK AREA    *
029900*    IF THIS IS THE FIRST CALL OF THIS PROGRAM    *
030000***************************************************
030100*
030200     IF  ACCESS-METHOD-NOT-SET
030300         PERFORM Z000-PROGRAM-INITIALIZATION
030400            THRU Z099-PI-EXIT.
030500*
030600**************************************************************
030700*    PROCESS THE FILE DEPENDING OF THE PROCESSING OPTION.    *
030800**************************************************************
030900*
031000     IF  ACCESS-IS-SEQUENTIAL
031100         PERFORM S000-SEQUENTIAL-ACCESS
031200            THRU S999-SA-EXIT
031300     ELSE
031400         IF  ACCESS-IS-DYNAMIC
031500             PERFORM D000-DYNAMIC-ACCESS
031600                THRU D999-DA-EXIT
031700         ELSE
031800             PERFORM R000-RANDOM-ACCESS
031900                THRU R999-RA-EXIT.
032000*
032100*****************************************************
032200*    MOVE THE STATUS CODE AND RETURN CODE TO        *
032300*    THEIR RESPECTIVE FIELDS IN COPYBOOK SS02WS.    *
032400*****************************************************
032500*
032600     MOVE MTRDRB-STATUS          TO SS02WS-FILE-STATUS.
032700     MOVE MTRDRB-RETURN          TO SS02WS-FILE-RETURN.
032800*
032900 A999-GOBACK.
033000*
033100     GOBACK.
033200/
033300 D000-DYNAMIC-ACCESS.
033400*
033500     GO TO D100-DA-INVALID-REQUEST
033600           D100-DA-INVALID-REQUEST
033700           D100-DA-INVALID-REQUEST
033800           D110-DA-OPEN-INPUT
033900           D120-DA-OPEN-OUTPUT
034000           D130-DA-OPEN-I-O
034100           D100-DA-INVALID-REQUEST
034200           D100-DA-INVALID-REQUEST
034300           D100-DA-INVALID-REQUEST
034400           D140-DA-START-GTE
034500           D150-DA-START-EQUAL
034600           D160-DA-READ-SEQ
034700           D170-DA-READ-RANDOM
034800           D180-DA-WRITE
034900           D190-DA-REWRITE
035000           D200-DA-DELETE
035100           D210-DA-CLOSE
035200           DEPENDING ON MTRDRB-IO-REQUEST.
035300*
035400 D100-DA-INVALID-REQUEST.
035500*
035600     MOVE MTRDRB-IO-REQUEST      TO SS02WS-ABEND-REQUEST.
035700     MOVE '- BAD I-O REQ - MTRD' TO SS02WS-ABENDMSG8.
035800     GO TO Z950-ABORT.
035900*
036000 D110-DA-OPEN-INPUT.
036100*
036200     OPEN INPUT MTRD-FILE-DYN.
036300*
036400     IF  WS-STATUS IS EQUAL TO '97'
036500         MOVE '97'               TO MTRDRB-OPEN-STATUS
036600         MOVE LOW-VALUES         TO WS-RETURN
036700         MOVE ZEROS              TO WS-STATUS.
036800*
036900     MOVE 'DYN'                  TO WS-SM-ACCESS.
037000     MOVE 'INPUT'                TO WS-SM-OPENED.
037100     MOVE '- OPEN  ERROR - MTRD' TO SS02WS-ABENDMSG8.
037200     GO TO D900-DA-CHECK-STATUS.
037300*
037400 D120-DA-OPEN-OUTPUT.
037500*
037600     OPEN OUTPUT MTRD-FILE-DYN.
037700*
037800     IF  WS-STATUS IS EQUAL TO '97'
037900         MOVE '97'               TO MTRDRB-OPEN-STATUS
038000         MOVE LOW-VALUES         TO WS-RETURN
038100         MOVE ZEROS              TO WS-STATUS.
038200*
038300     MOVE 'DYN'                  TO WS-SM-ACCESS.
038400     MOVE 'OUTPUT'               TO WS-SM-OPENED.
038500     MOVE '- OPEN  ERROR - MTRD' TO SS02WS-ABENDMSG8.
038600     GO TO D900-DA-CHECK-STATUS.
038700*
038800 D130-DA-OPEN-I-O.
038900*
039000     OPEN I-O MTRD-FILE-DYN.
039100*
039200     MOVE 'DYN'                  TO WS-SM-ACCESS.
039300     MOVE 'I-O'                  TO WS-SM-OPENED.
039400     MOVE '- OPEN  ERROR - MTRD' TO SS02WS-ABENDMSG8.
039500     GO TO D900-DA-CHECK-STATUS.
039600*
039700 D140-DA-START-GTE.
039800*
039900     MOVE MTRDIO-KEY             TO MTRD-DYN-KEY.
040000     START MTRD-FILE-DYN
040100           KEY IS NOT LESS THAN MTRD-DYN-KEY.
040200*
040300     MOVE '- START ERROR - MTRD' TO SS02WS-ABENDMSG8.
040400     GO TO D900-DA-CHECK-STATUS.
040500*
040600 D150-DA-START-EQUAL.
040700*
040800     MOVE MTRDIO-KEY             TO MTRD-DYN-KEY.
040900     START MTRD-FILE-DYN
041000           KEY IS EQUAL TO MTRD-DYN-KEY.
041100*
041200     MOVE '- START ERROR - MTRD' TO SS02WS-ABENDMSG8.
041300     GO TO D900-DA-CHECK-STATUS.
041400*
041500 D160-DA-READ-SEQ.
041600*
041700     READ MTRD-FILE-DYN NEXT RECORD
041800                                 INTO MTRDIO-RECORD.
041900*
042000     ADD 1                       TO WS-SC-READS.
042100     MOVE '- READ  ERROR - MTRD' TO SS02WS-ABENDMSG8.
042200     GO TO D900-DA-CHECK-STATUS.
042300*
042400 D170-DA-READ-RANDOM.
042500*
042600     MOVE MTRDIO-KEY             TO MTRD-DYN-KEY.
042700     READ MTRD-FILE-DYN          INTO MTRDIO-RECORD.
042800*
042900     ADD 1                       TO WS-SC-READS.
043000     MOVE '- READ  ERROR - MTRD' TO SS02WS-ABENDMSG8.
043100     GO TO D900-DA-CHECK-STATUS.
043200*
043300 D180-DA-WRITE.
043400*
043500     WRITE MTRD-DYN-RECORD       FROM MTRDIO-RECORD.
043600*
043700     ADD 1                       TO WS-SC-WRITES.
043800     MOVE '- WRITE ERROR - MTRD' TO SS02WS-ABENDMSG8.
043900     GO TO D900-DA-CHECK-STATUS.
044000*
044100 D190-DA-REWRITE.
044200*
044300     REWRITE MTRD-DYN-RECORD     FROM MTRDIO-RECORD.
044400*
044500     ADD 1                       TO WS-SC-REWRITES.
044600     MOVE '- REWRT ERROR - MTRD' TO SS02WS-ABENDMSG8.
044700     GO TO D900-DA-CHECK-STATUS.
044800*
044900 D200-DA-DELETE.
045000*
045100     MOVE MTRDIO-KEY             TO MTRD-DYN-KEY.
045200     DELETE MTRD-FILE-DYN RECORD.
045300*
045400     ADD 1                       TO WS-SC-DELETES.
045500     MOVE '- DELET ERROR - MTRD' TO SS02WS-ABENDMSG8.
045600     GO TO D900-DA-CHECK-STATUS.
045700*
045800 D210-DA-CLOSE.
045900*
046000     MOVE SPACE                  TO WS-ACCESS-METHOD.
046100     CLOSE  MTRD-FILE-DYN.
046200*
046300     PERFORM Z100-DISPLAY-THE-SUMMARY
046400        THRU Z199-DTS-EXIT.
046500*
046600     MOVE '- CLOSE ERROR - MTRD' TO SS02WS-ABENDMSG8.
046700     GO TO D900-DA-CHECK-STATUS.
046800*
046900 D900-DA-CHECK-STATUS.
047000*
047100     MOVE WS-STATUS              TO MTRDRB-STATUS.
047200     MOVE WS-RETURN              TO MTRDRB-RETURN.
047300*
047400     IF  MTRDRB-STATUS IS EQUAL  TO MTRDRB-TEMP-STATUS-1   OR
047500         MTRDRB-STATUS IS EQUAL  TO MTRDRB-TEMP-STATUS-2   OR
047600         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-1   OR
047700         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-2   OR
047800         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-3   OR
047900         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-4   OR
048000         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-5
048100         MOVE ZERO               TO MTRDRB-TEMP-STATUS-1
048200         MOVE ZERO               TO MTRDRB-TEMP-STATUS-2
048300     ELSE
048400         GO TO Z900-ABORT.
048500*
048600 D999-DA-EXIT.
048700     EXIT.
048800/
048900 R000-RANDOM-ACCESS.
049000*
049100     GO TO R100-RA-INVALID-REQUEST
049200           R100-RA-INVALID-REQUEST
049300           R100-RA-INVALID-REQUEST
049400           R100-RA-INVALID-REQUEST
049500           R100-RA-INVALID-REQUEST
049600           R100-RA-INVALID-REQUEST
049700           R110-RA-OPEN-INPUT
049800           R120-RA-OPEN-OUTPUT
049900           R130-RA-OPEN-I-O
050000           R100-RA-INVALID-REQUEST
050100           R100-RA-INVALID-REQUEST
050200           R100-RA-INVALID-REQUEST
050300           R140-RA-READ-RANDOM
050400           R150-RA-WRITE
050500           R160-RA-REWRITE
050600           R170-RA-DELETE
050700           R180-RA-CLOSE
050800           DEPENDING ON MTRDRB-IO-REQUEST.
050900*
051000 R100-RA-INVALID-REQUEST.
051100*
051200     MOVE MTRDRB-IO-REQUEST      TO SS02WS-ABEND-REQUEST.
051300     MOVE '- BAD I-O REQ - MTRD' TO SS02WS-ABENDMSG8.
051400     GO TO Z950-ABORT.
051500*
051600 R110-RA-OPEN-INPUT.
051700*
051800     OPEN INPUT MTRD-FILE-RDM.
051900*
052000     IF  WS-STATUS IS EQUAL TO '97'
052100         MOVE '97'               TO MTRDRB-OPEN-STATUS
052200         MOVE LOW-VALUES         TO WS-RETURN
052300         MOVE ZEROS              TO WS-STATUS.
052400*
052500     MOVE 'RDM'                  TO WS-SM-ACCESS.
052600     MOVE 'INPUT'                TO WS-SM-OPENED.
052700     MOVE '- OPEN  ERROR - MTRD' TO SS02WS-ABENDMSG8.
052800     GO TO R900-RA-CHECK-STATUS.
052900*
053000 R120-RA-OPEN-OUTPUT.
053100*
053200     OPEN OUTPUT MTRD-FILE-RDM.
053300*
053400     IF  WS-STATUS IS EQUAL TO '97'
053500         MOVE '97'               TO MTRDRB-OPEN-STATUS
053600         MOVE LOW-VALUES         TO WS-RETURN
053700         MOVE ZEROS              TO WS-STATUS.
053800*
053900     MOVE 'RDM'                  TO WS-SM-ACCESS.
054000     MOVE 'OUTPUT'               TO WS-SM-OPENED.
054100     MOVE '- OPEN  ERROR - MTRD' TO SS02WS-ABENDMSG8.
054200     GO TO R900-RA-CHECK-STATUS.
054300*
054400 R130-RA-OPEN-I-O.
054500*
054600     OPEN I-O MTRD-FILE-RDM.
054700*
054800     MOVE 'RDM'                  TO WS-SM-ACCESS.
054900     MOVE 'I-O'                  TO WS-SM-OPENED.
055000     MOVE '- OPEN  ERROR - MTRD' TO SS02WS-ABENDMSG8.
055100     GO TO R900-RA-CHECK-STATUS.
055200*
055300 R140-RA-READ-RANDOM.
055400*
055500     MOVE MTRDIO-KEY             TO MTRD-RDM-KEY.
055600     READ MTRD-FILE-RDM          INTO MTRDIO-RECORD.
055700*
055800     ADD 1                       TO WS-SC-READS.
055900     MOVE '- READ  ERROR - MTRD' TO SS02WS-ABENDMSG8.
056000     GO TO R900-RA-CHECK-STATUS.
056100*
056200 R150-RA-WRITE.
056300*
056400     WRITE MTRD-RDM-RECORD       FROM MTRDIO-RECORD.
056500*
056600     ADD 1                       TO WS-SC-WRITES.
056700     MOVE '- WRITE ERROR - MTRD' TO SS02WS-ABENDMSG8.
056800     GO TO R900-RA-CHECK-STATUS.
056900*
057000 R160-RA-REWRITE.
057100*
057200     REWRITE MTRD-RDM-RECORD     FROM MTRDIO-RECORD.
057300*
057400     ADD 1                       TO WS-SC-REWRITES.
057500     MOVE '- REWRT ERROR - MTRD' TO SS02WS-ABENDMSG8.
057600     GO TO R900-RA-CHECK-STATUS.
057700*
057800 R170-RA-DELETE.
057900*
058000     MOVE MTRDIO-KEY             TO MTRD-RDM-KEY.
058100     DELETE MTRD-FILE-RDM RECORD.
058200*
058300     ADD 1                       TO WS-SC-DELETES.
058400     MOVE '- DELET ERROR - MTRD' TO SS02WS-ABENDMSG8.
058500     GO TO R900-RA-CHECK-STATUS.
058600*
058700 R180-RA-CLOSE.
058800*
058900     MOVE SPACE                  TO WS-ACCESS-METHOD.
059000     CLOSE  MTRD-FILE-RDM.
059100*
059200     PERFORM Z100-DISPLAY-THE-SUMMARY
059300        THRU Z199-DTS-EXIT.
059400*
059500     MOVE '- CLOSE ERROR - MTRD' TO SS02WS-ABENDMSG8.
059600     GO TO R900-RA-CHECK-STATUS.
059700*
059800 R900-RA-CHECK-STATUS.
059900*
060000     MOVE WS-STATUS              TO MTRDRB-STATUS.
060100     MOVE WS-RETURN              TO MTRDRB-RETURN.
060200*
060300     IF  MTRDRB-STATUS IS EQUAL  TO MTRDRB-TEMP-STATUS-1   OR
060400         MTRDRB-STATUS IS EQUAL  TO MTRDRB-TEMP-STATUS-2   OR
060500         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-1   OR
060600         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-2   OR
060700         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-3   OR
060800         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-4   OR
060900         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-5
061000         MOVE ZERO               TO MTRDRB-TEMP-STATUS-1
061100         MOVE ZERO               TO MTRDRB-TEMP-STATUS-2
061200     ELSE
061300         GO TO Z900-ABORT.
061400*
061500 R999-RA-EXIT.
061600     EXIT.
061700/
061800 S000-SEQUENTIAL-ACCESS.
061900*
062000     GO TO S110-SA-OPEN-INPUT
062100           S120-SA-OPEN-OUTPUT
062200           S130-SA-OPEN-I-O
062300           S100-SA-INVALID-REQUEST
062400           S100-SA-INVALID-REQUEST
062500           S100-SA-INVALID-REQUEST
062600           S100-SA-INVALID-REQUEST
062700           S100-SA-INVALID-REQUEST
062800           S100-SA-INVALID-REQUEST
062900           S140-SA-START-GTE
063000           S150-SA-START-EQUAL
063100           S160-SA-READ-SEQ
063200           S100-SA-INVALID-REQUEST
063300           S170-SA-WRITE
063400           S180-SA-REWRITE
063500           S190-SA-DELETE
063600           S200-SA-CLOSE
063700           DEPENDING ON MTRDRB-IO-REQUEST.
063800*
063900 S100-SA-INVALID-REQUEST.
064000*
064100     MOVE MTRDRB-IO-REQUEST      TO SS02WS-ABEND-REQUEST.
064200     MOVE '- BAD I-O REQ - MTRD' TO SS02WS-ABENDMSG8.
064300     GO TO Z950-ABORT.
064400*
064500 S110-SA-OPEN-INPUT.
064600*
064700     OPEN INPUT MTRD-FILE-SEQ.
064800*
064900     IF  WS-STATUS IS EQUAL TO '97'
065000         MOVE '97'               TO MTRDRB-OPEN-STATUS
065100         MOVE LOW-VALUES         TO WS-RETURN
065200         MOVE ZEROS              TO WS-STATUS.
065300*
065400     MOVE 'SEQ'                  TO WS-SM-ACCESS.
065500     MOVE 'INPUT'                TO WS-SM-OPENED.
065600     MOVE '- OPEN  ERROR - MTRD' TO SS02WS-ABENDMSG8.
065700     GO TO S900-SA-CHECK-STATUS.
065800*
065900 S120-SA-OPEN-OUTPUT.
066000*
066100     OPEN OUTPUT MTRD-FILE-SEQ.
066200*
066300     IF  WS-STATUS IS EQUAL TO '97'
066400         MOVE '97'               TO MTRDRB-OPEN-STATUS
066500         MOVE LOW-VALUES         TO WS-RETURN
066600         MOVE ZEROS              TO WS-STATUS.
066700*
066800     MOVE 'SEQ'                  TO WS-SM-ACCESS.
066900     MOVE 'OUTPUT'               TO WS-SM-OPENED.
067000     MOVE '- OPEN  ERROR - MTRD' TO SS02WS-ABENDMSG8.
067100     GO TO S900-SA-CHECK-STATUS.
067200*
067300 S130-SA-OPEN-I-O.
067400*
067500     OPEN I-O MTRD-FILE-SEQ.
067600*
067700     MOVE 'SEQ'                  TO WS-SM-ACCESS.
067800     MOVE 'I-O'                  TO WS-SM-OPENED.
067900     MOVE '- OPEN  ERROR - MTRD' TO SS02WS-ABENDMSG8.
068000     GO TO S900-SA-CHECK-STATUS.
068100*
068200 S140-SA-START-GTE.
068300*
068400     MOVE MTRDIO-KEY             TO MTRD-SEQ-KEY.
068500     START MTRD-FILE-SEQ
068600           KEY IS NOT LESS THAN MTRD-SEQ-KEY.
068700*
068800     MOVE '- START ERROR - MTRD' TO SS02WS-ABENDMSG8.
068900     GO TO S900-SA-CHECK-STATUS.
069000*
069100 S150-SA-START-EQUAL.
069200*
069300     MOVE MTRDIO-KEY             TO MTRD-SEQ-KEY.
069400     START MTRD-FILE-SEQ
069500           KEY IS EQUAL TO MTRD-SEQ-KEY.
069600*
069700     MOVE '- START ERROR - MTRD' TO SS02WS-ABENDMSG8.
069800     GO TO S900-SA-CHECK-STATUS.
069900*
070000 S160-SA-READ-SEQ.
070100*
070200     READ MTRD-FILE-SEQ          INTO MTRDIO-RECORD.
070300*
070400     ADD 1                       TO WS-SC-READS.
070500     MOVE '- READ  ERROR - MTRD' TO SS02WS-ABENDMSG8.
070600     GO TO S900-SA-CHECK-STATUS.
070700*
070800 S170-SA-WRITE.
070900*
071000     WRITE MTRD-SEQ-RECORD       FROM MTRDIO-RECORD.
071100*
071200     ADD 1                       TO WS-SC-WRITES.
071300     MOVE '- WRITE ERROR - MTRD' TO SS02WS-ABENDMSG8.
071400     GO TO S900-SA-CHECK-STATUS.
071500*
071600 S180-SA-REWRITE.
071700*
071800     REWRITE MTRD-SEQ-RECORD     FROM MTRDIO-RECORD.
071900*
072000     ADD 1                       TO WS-SC-REWRITES.
072100     MOVE '- REWRT ERROR - MTRD' TO SS02WS-ABENDMSG8.
072200     GO TO S900-SA-CHECK-STATUS.
072300*
072400 S190-SA-DELETE.
072500*
072600     MOVE MTRDIO-KEY             TO MTRD-SEQ-KEY.
072700     DELETE MTRD-FILE-SEQ RECORD.
072800*
072900     ADD 1                       TO WS-SC-DELETES.
073000     MOVE '- DELET ERROR - MTRD' TO SS02WS-ABENDMSG8.
073100     GO TO S900-SA-CHECK-STATUS.
073200*
073300 S200-SA-CLOSE.
073400*
073500     MOVE SPACE                  TO WS-ACCESS-METHOD.
073600     CLOSE MTRD-FILE-SEQ.
073700*
073800     PERFORM Z100-DISPLAY-THE-SUMMARY
073900        THRU Z199-DTS-EXIT.
074000*
074100     MOVE '- CLOSE ERROR - MTRD' TO SS02WS-ABENDMSG8.
074200     GO TO S900-SA-CHECK-STATUS.
074300*
074400 S900-SA-CHECK-STATUS.
074500*
074600     MOVE WS-STATUS              TO MTRDRB-STATUS.
074700     MOVE WS-RETURN              TO MTRDRB-RETURN.
074800*
074900     IF  MTRDRB-STATUS IS EQUAL  TO MTRDRB-TEMP-STATUS-1   OR
075000         MTRDRB-STATUS IS EQUAL  TO MTRDRB-TEMP-STATUS-2   OR
075100         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-1   OR
075200         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-2   OR
075300         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-3   OR
075400         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-4   OR
075500         MTRDRB-STATUS IS EQUAL  TO MTRDRB-PERM-STATUS-5
075600         MOVE ZERO               TO MTRDRB-TEMP-STATUS-1
075700         MOVE ZERO               TO MTRDRB-TEMP-STATUS-2
075800     ELSE
075900         GO TO Z900-ABORT.
076000*
076100 S999-SA-EXIT.
076200     EXIT.
076300/
076400 Z000-PROGRAM-INITIALIZATION.
076500*
076600************************************************************
076700*    THE CALLING PROGRAM MUST SUPPLY THE PROGRAM ID TO     *
076800*    ENSURE THAT ANY SUBSEQUENT ABEND CAN BE TRACED TO     *
076900*    IT.  IF THE PROGRAM ID IS NOT SUPPLIED, THE ACCESS    *
077000*    ROUTINE ABENDS HERE.                                  *
077100************************************************************
077200*
077300     IF  SS02WS-ABEND-PROG-ID IS EQUAL TO SPACES
077400         MOVE '- BAD PROG NAME - MTRD'
077500                                 TO SS02WS-ABENDMSG8
077600         MOVE 'BADPRO'           TO SS02WS-ABEND-PROG-ID
077700         GO TO Z950-ABORT.
077800*
077900     MOVE SS02WS-ABEND-PROG-ID   TO WS-SM-PROG-ID.
078000*
078100*************************************************************
078200*    SINCE THIS ROUTINE IS PERFORMED ONLY ONCE DURING       *
078300*    THE EXECUTION OF A CALLING PROGRAM, THE FIRST          *
078400*    REQUEST MUST BE FOR AN OPEN.  SET THE ACCESS METHOD    *
078500*    (SEQENTIAL, DYNAMIC, OR RANDOM), OR ISSUE AN ABEND     *
078600*    IF THE REQUEST IS NOT FOR AN OPEN.                     *
078700*************************************************************
078800*
078900     IF  MTRDRB-OPEN-INPUT    OR
079000         MTRDRB-OPEN-OUTPUT   OR
079100         MTRDRB-OPEN-IO
079200         MOVE 'S'                TO WS-ACCESS-METHOD.
079300*
079400     IF  MTRDRB-OPEN-INPUT-DYN    OR
079500         MTRDRB-OPEN-OUTPUT-DYN   OR
079600         MTRDRB-OPEN-IO-DYN
079700         MOVE 'D'                TO WS-ACCESS-METHOD.
079800*
079900     IF  MTRDRB-OPEN-INPUT-RDM    OR
080000         MTRDRB-OPEN-OUTPUT-RDM   OR
080100         MTRDRB-OPEN-IO-RDM
080200         MOVE 'R'                TO WS-ACCESS-METHOD.
080300*
080400     IF  ACCESS-METHOD-NOT-SET
080500         MOVE 'SMTRD'            TO SS02WS-ABEND-CODE-X
080600         MOVE MTRDRB-IO-REQUEST  TO WS-IO-REQUEST
080700         MOVE WS-IO-REQUEST      TO SS02WS-ABEND-REQUEST
080800         MOVE 'ILLEGAL ACCESS REQUEST'
080900                                 TO SS02WS-ABENDMSG8
081000         GO TO Z950-ABORT.
081100*
081200 Z099-PI-EXIT.
081300     EXIT.
081400*
081500 Z100-DISPLAY-THE-SUMMARY.
081600*
081700     MOVE WS-SC-READS            TO WS-SM-READS.
081800     MOVE WS-SC-WRITES           TO WS-SM-WRITES.
081900     MOVE WS-SC-REWRITES         TO WS-SM-REWRITES.
082000     MOVE WS-SC-DELETES          TO WS-SM-DELETES.
082100     DISPLAY WS-SUMMARY-MESSAGE.
082200*
082300     INITIALIZE WS-SUMMARY-COUNTERS.
082400*
082500 Z199-DTS-EXIT.
082600     EXIT.
082700/
082800 Z900-ABORT.
082900*
083000     MOVE 'SMTRD'                TO SS02WS-ABEND-CODE-X.
083100     MOVE MTRDRB-STATUS          TO SS02WS-ABEND-STATUS.
083200     MOVE MTRDRB-RETURN-CODE     TO SS02WS-ABEND-RETURN.
083300     MOVE MTRDRB-FUNCTION-CODE   TO SS02WS-ABEND-FUNCTION.
083400     MOVE MTRDRB-FEEDBACK-CODE   TO SS02WS-ABEND-FEEDBACK.
083500     MOVE MTRDRB-IO-REQUEST      TO WS-IO-REQUEST.
083600     MOVE WS-IO-REQUEST          TO SS02WS-ABEND-REQUEST.
083700*
083800 Z950-ABORT.
083900*
084000     PERFORM SS02PD-ABEND        THRU SS02PD-ABEND-EXIT.
084100*
084200 Z999-ABORT-EXIT.
084300     EXIT.
084400/
084500********************************
084600*    STANDARD ABEND ROUTINE    *
084700********************************
084800*
084900     COPY SS02PD.
085000*
