000100 IDENTIFICATION DIVISION.
000200 PROGRAM-ID. MTSEAB.
000201*       RELEASE DATE=08/24/01.        REVISION LEVEL=08.06      * ++++++++
000202***************************************************************** ++++++++
000203*WARNING.  THIS COMPUTER PROGRAM IS PROTECTED BY COPYRIGHT LAW  * ++++++++
000204*AND INTERNATIONAL TREATIES.  UNAUTHORIZED REPRODUCTION OR      * ++++++++
000205*DISTRIBUTION OF THIS PROGRAM, OR ANY PORTION OF IT, MAY RESULT * ++++++++
000206*IN SEVERE CIVIL AND CRIMINAL PENATLIES, AND WILL BE PROSECUTED * ++++++++
000207*TO THE MAXIMUM EXTENT POSSIBLE UNDER THE LAW.                  * ++++++++
000208*COPYRIGHT 1999 PAYSYS INTERNATIONAL, INC.  ALL RIGHTS RESERVED.* ++++++++
000209***************************************************************** ++++++++
000300******************************************************************
000400*                                                                *
000500*    ---------------MERCHANT BANKCARD SYSTEM---------------      *
000600*                                                                *
000700*          MTSEAB - MTSE FILE COMMON BATCH I/O ROUTINE           *
000800*                                                                *
000900*                VARIABLE LENGTH SEQUENTIAL FILE                 *
001000*                                                                *
001100*    -----------------CUSTOM STATEMENT FILE----------------      *
001200*                                                                *
001300******************************************************************
001400*                                                                *
001500*    COPYBOOKS WHICH MUST APPEAR IN YOUR BATCH PROGRAM:          *
001600*                                                                *
001700*    (WS) MB00RB - BATCH REQUEST BLOCK                           *
001800*    (WS) MTSEIO - I/O AREA                                      *
001900*    (WS) SS02WS - STANDARD ABEND ROUTINE WORK AREA              *
002000*    (PD) MB00PD - PROCEDURE DIVISION CALL STATEMENT             *
002100*                                                                *
002200******************************************************************
002300*                                                                *
002400*    TO USE THIS ROUTINE.........                                *
002500*                                                                *
002600* 1. HOUSEKEEPING DUTIES:                                        *
002700*                                                                *
002800*    A. IN THE HOUSEKEEPING SECTION OF YOUR PROGRAM, MOVE THE    *
002900*       NAME OF THE PROGRAM USING THIS ROUTINE TO THE FIELD      *
003000*       'SS02WS-ABEND-PROG-ID'. THIS FIELD IS USED AS PART OF THE*
003100*       STANDARD ABEND MESSAGES IF A PROGRAM ABORTS WITHIN THIS  *
003200*       ACCESS ROUTINE.  IF THE FIELD 'SS02WS-ABEND-PROG-ID' IS  *
003300*       LEFT BLANK, THIS ROUTINE WILL FORCE AN ABEND SITUATION.  *
003400*                                                                *
003500*    B. BEFORE PERFORMING THE ACCESS ROUTINE, MOVE A LITERAL TO  *
003600*       THE FIELD 'SS02WS-ABEND-LOCATION'. THIS FIELD CAN BE USED*
003700*       TO INDICATE WHERE THE ROUTINE IS BEING 'FROM' IN CASE    *
003800*       OF ABNORMAL TERMINATION. (E.G. DEBUGGING ASSISTANCE)     *
003900*                                                                *
004000*    C. SET THE RETURN CODES WHICH YOU WANT, FOR THE DURATION    *
004100*       OF THIS PROGRAM, TO BE CONSIDERED VALID IN THE FIELDS    *
004200*       'MTSERB-PERM-STATUS-1 TO -5'. THESE FIELDS ARE INITIAL-  *
004300*       IZED TO ZERO (AS ZERO IS ALWAYS AN ACCEPTABLE RETURN     *
004400*       CODE).  THIS ROUTINE WILL (IN ALL I-O REQUESTS) SUCCESS- *
004500*       FULLY SATISFY YOUR PERFORM REQUEST IF ANY OF THE REQUESTS*
004600*       ENCOUNTER ANY OF THE PERMANENT STATUS CODES 1-5.         *
004700*                                                                *
004800* 2. SET ONE OF THE FOLLOWING CONDITION NAMES TO 'TRUE' TO SET   *
004900*    THE FILE REQUEST:                                           *
005000*                                                                *
005100*        CONDITION NAME                EXPLANATION               *
005200*   *----------------------***---------------------------------* *
005300*                                                                *
005400*    MTSERB-OPEN-INPUT      - OPEN THE FILE AS INPUT.            *
005500*    MTSERB-OPEN-OUTPUT     - OPEN THE FILE AS OUTPUT.           *
005600*    MTSERB-OPEN-IO         - OPEN THE FILE AS I-O.              *
005700*    MTSERB-READ-SEQ        - READ THE NEXT SEQUENTIAL RECORD    *
005800*                             IN THE FILE.                       *
005900*    MTSERB-WRITE           - WRITE A RECORD (THE RECORD MUST    *
006000*                             BE IN 'MTSEIO-RECORD').            *
006100*    MTSERB-REWRITE         - REWRITE A RECORD (THE RECORD MUST  *
006200*                             BE IN 'MTSEIO-RECORD').            *
006300*    MTSERB-CLOSE           - CLOSE THE FILE.                    *
006400*                                                                *
006500* 3. SET ONE OR BOTH OF THE 'TEMPORARY' RETURN CODE FIELDS       *
006600*    'MTSERB-TEMP-STATUS-1 AND -2'.  THESE TWO RETURN CODES      *
006700*    ARE TO BE USED ON A PER USE BASIS OF THIS ROUTINE.          *
006800*    THESE TWO RETURN CODES ARE INITIALIZED TO ZERO AND ARE      *
006900*    BOTH RESET TO ZERO AFTER EACH CALL OF THIS PROGRAM.         *
007000*    THE TEMPORARY RETURN CODE FIELDS ARE CHECKED FIRST AND      *
007100*    THEN THE PERMANENT RETURN CODES (POINT 1.C ABOVE) WILL      *
007200*    BE CHECKED.                                                 *
007300*                                                                *
007400* 4. PERFORM MB00PD-MTSE-ACCESS THRU MB00PD-MTSE-ACCESS-EXIT.    *
007500*                                                                *
007600*    A. YOU MUST HANDLE MANUALLY ANY RETURN CODE (EITHER TEMP    *
007700*       OR PERM) THAT YOU REQUESTED, AND IF NEEDED, YOUR OWN     *
007800*       ABEND REQUEST.                                           *
007900*                                                                *
008000*    B. ALL ACCESS ROUTINES MOVE THE FILE STATUS TO THE FIELD    *
008100*       SS02WS-FILE-STATUS IN COPYBOOK SS02WS. USE THE '88' LEVEL*
008200*       NAMES TO TEST YOUR MANUAL STATUS CHECKS.  ALSO IN COPY   *
008300*       BOOK SS02WS, USE THE 'WS-' FILE STATUS DATA NAMES WHEN   *
008400*       SETTING THE PERM OR TEMP FILE STATUS CODES PRIOR TO      *
008500*       PERFORMING THE ACCESS ROUTINE.                           *
008600*                                                                *
008700******************************************************************
008800/
008900 ENVIRONMENT DIVISION.
009000*
009100 CONFIGURATION SECTION.
009200 SOURCE-COMPUTER.            IBM-4341.
009300 OBJECT-COMPUTER.            IBM-4341.
009400*
009500 INPUT-OUTPUT SECTION.
009600*
009700 FILE-CONTROL.
009800*
009900     SELECT  MTSE-FILE
010000             ASSIGN              TO SYS002-UT-3380-S-MTSE
010100             FILE STATUS         IS WS-STATUS.
010200/
010300 DATA DIVISION.
010400*
010500 FILE SECTION.
010600*
010700 FD  MTSE-FILE
010800     RECORDING MODE IS V
010900     RECORD CONTAINS 201 TO 950 CHARACTERS
011000     BLOCK CONTAINS 0 CHARACTERS.
011100*
011200 01  MTSE-FD-MAX-RECORD.
011300     03  FILLER              PIC  X(950).
011400*
011500 01  MTSE-FD-RECORD.
011600     03  MTSE-FD-FIXED-DATA  PIC  X(200).
011700     03  MTSE-FD-VAR-DATA                    OCCURS 1 TO 750 TIMES
011800                                             DEPENDING ON
011900                                             WS-DATA-LENGTH.
012000         05  MTSE-FD-VD-BYTE PIC  X(01).
012100*
012200*
012300/
012400 WORKING-STORAGE SECTION.
012500*
012600 01  FILLER                  PIC  X(12)      VALUE '** WS-BEG **'.
012700*
012800 01  FILLER                  PIC  X(18)      VALUE
012900     'FIRST CALL SWITCH:'.
013000*
013100 01  WS-FIRST-CALL-SW        PIC  X(01)      VALUE 'Y'.
013200     88  WS-FIRST-CALL-SW-IS-YES             VALUE 'Y'.
013300*
013400 01  FILLER                  PIC  X(12)      VALUE
013500     'FILE STATUS:'.
013600*
013700 01  WS-STATUS               PIC  X(02)      VALUE ZERO.
013800*
013900 01  FILLER                  PIC  X(12)      VALUE
014000     'I-O REQUEST:'.
014100*
014200 01  WS-IO-REQUEST           PIC  9(02)      VALUE ZERO.
014300*
014400 01  FILLER                  PIC  X(12)      VALUE
014500     'DATA LENGTH:'.
014600*
014700 01  WS-DATA-LENGTH          PIC S9(04)      BINARY
014800                                             VALUE ZERO.
014900     88  WS-MAXIMUM-DATA-LENGTH              VALUE +750.
015000*
015100 01  WS-SEQ-COUNT            PIC S9(11)      COMP-3
015200                                             VALUE ZERO.
015300*
015400 01  FILLER                  PIC  X(28)      VALUE
015500     'PROCESSING SUMMARY COUNTERS:'.
015600*
015700 01  WS-SUMMARY-COUNTERS.
015800     03  WS-SC-READS         PIC S9(09)      COMP-3
015900                                             VALUE ZERO.
016000     03  WS-SC-WRITES        PIC S9(09)      COMP-3
016100                                             VALUE ZERO.
016200     03  WS-SC-REWRITES      PIC S9(09)      COMP-3
016300                                             VALUE ZERO.
016400*
016500 01  FILLER                  PIC  X(27)      VALUE
016600     'PROCESSING SUMMARY MESSAGE:'.
016700*
016800 01  WS-SUMMARY-MESSAGE.
016900     03  FILLER              PIC  X(10)      VALUE '(PGMSTAT) '.
017000     03  WS-SM-PROG-ID       PIC  X(06)      VALUE SPACES.
017100     03  FILLER              PIC  X(03)      VALUE ' - '.
017200     03  WS-SM-FILE-ID       PIC  X(04)      VALUE 'MTSE'.
017300     03  FILLER              PIC  X(11)      VALUE ' - OPENED: '.
017400     03  WS-SM-ACCESS        PIC  X(03)      VALUE SPACES.
017500     03  FILLER              PIC  X(01)      VALUE SPACE.
017600     03  WS-SM-OPENED        PIC  X(06)      VALUE SPACES.
017700     03  FILLER              PIC  X(01)      VALUE SPACE.
017800     03  WS-SM-READS         PIC  ZZZZZZZZ9.
017900     03  FILLER              PIC  X(08)      VALUE ' READS, '.
018000     03  WS-SM-WRITES        PIC  ZZZZZZZZ9.
018100     03  FILLER              PIC  X(09)      VALUE ' WRITES, '.
018200     03  WS-SM-REWRITES      PIC  ZZZZZZZZ9.
018300     03  FILLER              PIC  X(09)      VALUE ' REWRITES'.
018400/
018500     COPY MTSERL REPLACING ==:MTSE:== BY ==MTSE==.
018600/
018700     COPY SS00WS.
018800/
018900 01  FILLER                  PIC  X(12)      VALUE '** WS-END **'.
019000/
019100 LINKAGE SECTION.
019200*
019300****************************
019400*    FILE REQUEST BLOCK    *
019500****************************
019600*
019700     COPY MB00RB REPLACING ==:MB00:== BY ==MTSE==.
019800*
019900******************
020000*    I/O AREA    *
020100******************
020200*
020300     COPY MTSEIO REPLACING ==:MTSE:== BY ==MTSE==.
020400*
020500*********************************
020600*    ABEND ROUTINE WORK AREA    *
020700*********************************
020800*
020900     COPY SS02WS.
021000/
021100 PROCEDURE DIVISION          USING MTSERB-WORK-AREA,
021200                                   MTSEIO-RECORD,
021300                                   SS02WS-ABEND-WORK-AREA.
021400*
021500 A000-MAIN-LINE-SECTION.
021600*
021700*
021800******************************************
021900*    SET THE ABEND WORK AREA IF THIS     *
022000*    IS THE FIRST CALL OF THE PROGRAM    *
022100******************************************
022200*
022300     IF  WS-FIRST-CALL-SW-IS-YES
022400         PERFORM Z000-PROGRAM-INITIALIZATION
022500            THRU Z099-PI-EXIT.
022600*
022700**************************
022800*    PROCESS THE FILE    *
022900**************************
023000*
023100     PERFORM S000-SEQUENTIAL-ACCESS
023200        THRU S999-SA-EXIT.
023300*
023400************************************************
023500*    MOVE THE STATUS CODE TO ITS RESPECTIVE    *
023600*    FIELD IN COPYBOOK SS02WS.                 *
023700************************************************
023800*
023900     MOVE MTSERB-STATUS          TO SS02WS-FILE-STATUS.
024000*
024100 A999-GOBACK.
024200*
024300     GOBACK.
024400/
024500 S000-SEQUENTIAL-ACCESS.
024600*
024700     GO TO S110-SA-OPEN-INPUT
024800           S120-SA-OPEN-OUTPUT
024900           S130-SA-OPEN-I-O
025000           S100-SA-INVALID-REQUEST
025100           S100-SA-INVALID-REQUEST
025200           S100-SA-INVALID-REQUEST
025300           S100-SA-INVALID-REQUEST
025400           S100-SA-INVALID-REQUEST
025500           S100-SA-INVALID-REQUEST
025600           S100-SA-INVALID-REQUEST
025700           S100-SA-INVALID-REQUEST
025800           S140-SA-READ-SEQ
025900           S100-SA-INVALID-REQUEST
026000           S150-SA-WRITE
026100           S160-SA-REWRITE
026200           S100-SA-INVALID-REQUEST
026300           S170-SA-CLOSE
026400           DEPENDING ON MTSERB-IO-REQUEST.
026500*
026600 S100-SA-INVALID-REQUEST.
026700*
026800     MOVE MTSERB-IO-REQUEST      TO SS02WS-ABEND-REQUEST.
026900     MOVE '- BAD I-O REQ - MTSE' TO SS02WS-ABENDMSG8.
027000     GO TO Z950-ABORT.
027100*
027200 S110-SA-OPEN-INPUT.
027300*
027400     OPEN INPUT MTSE-FILE.
027500*
027600     MOVE 'SEQ'                  TO WS-SM-ACCESS.
027700     MOVE 'INPUT'                TO WS-SM-OPENED.
027800     MOVE '- OPEN  ERROR - MTSE' TO SS02WS-ABENDMSG8.
027900     GO TO S900-SA-CHECK-STATUS.
028000*
028100 S120-SA-OPEN-OUTPUT.
028200*
028300     OPEN OUTPUT MTSE-FILE.
028400*
028500     MOVE 'SEQ'                  TO WS-SM-ACCESS.
028600     MOVE 'OUTPUT'               TO WS-SM-OPENED.
028700     MOVE '- OPEN  ERROR - MTSE' TO SS02WS-ABENDMSG8.
028800     MOVE ZERO                   TO WS-SEQ-COUNT.
028900     GO TO S900-SA-CHECK-STATUS.
029000*
029100 S130-SA-OPEN-I-O.
029200*
029300     OPEN I-O MTSE-FILE.
029400*
029500     MOVE 'SEQ'                  TO WS-SM-ACCESS.
029600     MOVE 'I-O'                  TO WS-SM-OPENED.
029700     MOVE '- OPEN  ERROR - MTSE' TO SS02WS-ABENDMSG8.
029800     GO TO S900-SA-CHECK-STATUS.
029900*
030000 S140-SA-READ-SEQ.
030100*
030200     SET WS-MAXIMUM-DATA-LENGTH  TO TRUE.
030300     READ MTSE-FILE              INTO MTSEIO-RECORD.
030400*
030500     ADD 1                       TO WS-SC-READS.
030600     MOVE '- READ  ERROR - MTSE' TO SS02WS-ABENDMSG8.
030700     GO TO S900-SA-CHECK-STATUS.
030800*
030900 S150-SA-WRITE.
031000*
031100     MOVE MTSEIO-RECORD          TO MTSE-RECORD.
031200     ADD  1                      TO WS-SEQ-COUNT.
031300     MOVE WS-SEQ-COUNT           TO MTSE-S-REC-ID-SEQ.
031400     MOVE MTSE-RECORD            TO MTSE-FD-MAX-RECORD.
031500     MOVE MTSE-RECORD            TO MTSEIO-RECORD.
031600*
031700     PERFORM  S800-SA-GET-LENGTH
031800        THRU  S899-SA-GL-EXIT.
031900*
032000     WRITE MTSE-FD-RECORD.
032100*
032200     ADD 1                       TO WS-SC-WRITES.
032300     MOVE '- WRITE ERROR - MTSE' TO SS02WS-ABENDMSG8.
032400     GO TO S900-SA-CHECK-STATUS.
032500*
032600 S160-SA-REWRITE.
032700*
032800     MOVE MTSEIO-RECORD          TO MTSE-FD-MAX-RECORD.
032900     MOVE MTSEIO-RECORD          TO MTSE-RECORD.
033000*
033100     PERFORM  S800-SA-GET-LENGTH
033200        THRU  S899-SA-GL-EXIT.
033300*
033400     REWRITE MTSE-FD-RECORD.
033500*
033600     ADD 1                       TO WS-SC-REWRITES.
033700     MOVE '- REWRT ERROR - MTSE' TO SS02WS-ABENDMSG8.
033800     GO TO S900-SA-CHECK-STATUS.
033900*
034000 S170-SA-CLOSE.
034100*
034200     MOVE SPACE                  TO WS-FIRST-CALL-SW.
034300     CLOSE MTSE-FILE.
034400*
034500     PERFORM Z100-DISPLAY-THE-SUMMARY
034600        THRU Z199-DTS-EXIT.
034700*
034800     MOVE '- CLOSE ERROR - MTSE' TO SS02WS-ABENDMSG8.
034900     GO TO S900-SA-CHECK-STATUS.
035000/
035100 S800-SA-GET-LENGTH.
035200*
035300     SET WS-MAXIMUM-DATA-LENGTH  TO TRUE.
035400*
035500     EVALUATE TRUE
035600         WHEN MTSE-S-PROCESSOR-DEMO
035700             MOVE LENGTH OF MTSE-PROC-DEMO
035800                                 TO WS-DATA-LENGTH
035900         WHEN MTSE-S-DEMO-DATA
036000             MOVE LENGTH OF MTSE-DEMO-DATA
036100                                 TO WS-DATA-LENGTH
036200         WHEN MTSE-S-STMNT-MSG
036300             MOVE LENGTH OF MTSE-STMNT-MSG
036400                                 TO WS-DATA-LENGTH
036500         WHEN (MTSE-S-BALANCE-SUMMARY
036600           OR  MTSE-S-MERCH-SUMMARY)
036700             MOVE LENGTH OF MTSE-BAL-SUMMARY
036800                                 TO WS-DATA-LENGTH
036900         WHEN MTSE-S-RESERVE-SUMMARY
037000             MOVE LENGTH OF MTSE-RESERVE-SUMM
037100                                 TO WS-DATA-LENGTH
037200         WHEN MTSE-S-RECOVERY-ADJ
037300             MOVE LENGTH OF MTSE-RECOVERY-ADJ
037400                                 TO WS-DATA-LENGTH
037500         WHEN MTSE-S-ADJ-SUMMARY
037600             MOVE LENGTH OF MTSE-ADJ-SUMMARY
037700                                 TO WS-DATA-LENGTH
037800         WHEN MTSE-S-USER-CR-SUMMARY
037900             MOVE LENGTH OF MTSE-USER-CREDIT
038000                                 TO WS-DATA-LENGTH
038100         WHEN MTSE-S-FEE-SUMMARY
038200             MOVE LENGTH OF MTSE-FEE-SUMMARY
038300                                 TO WS-DATA-LENGTH
038400         WHEN MTSE-S-DISBURSE-ACT-SUMM
038500             MOVE LENGTH OF MTSE-DISBURSE-ACTIVITY
038600                                 TO WS-DATA-LENGTH
038700         WHEN MTSE-S-DISBURSE-TOTALS
038800             MOVE LENGTH OF MTSE-DISBURSEMENT-TOTS
038900                                 TO WS-DATA-LENGTH
039000         WHEN MTSE-S-PRODUCT-SUMMARY
039100             MOVE LENGTH OF MTSE-PRODUCT-SUMMARY
039200                                 TO WS-DATA-LENGTH
039300         WHEN MTSE-S-STORE-SUMMARY
039400             MOVE LENGTH OF MTSE-STORE-SUMMARY
039500                                 TO WS-DATA-LENGTH
039600         WHEN MTSE-S-DEPOSIT-TRANS
039700             MOVE LENGTH OF MTSE-DEPOSIT-HISTORY
039800                                 TO WS-DATA-LENGTH
039900         WHEN MTSE-S-DETAIL-TRANS
040000             MOVE LENGTH OF MTSE-HISTORY-DATA
040100                                 TO WS-DATA-LENGTH
040200     END-EVALUATE.
040300*
040400 S899-SA-GL-EXIT.
040500     EXIT.
040600*
040700*
040800*
040900 S900-SA-CHECK-STATUS.
041000*
041100     MOVE WS-STATUS              TO MTSERB-STATUS.
041200*
041300     IF  MTSERB-STATUS IS EQUAL TO MTSERB-TEMP-STATUS-1   OR
041400         MTSERB-STATUS IS EQUAL TO MTSERB-TEMP-STATUS-2   OR
041500         MTSERB-STATUS IS EQUAL TO MTSERB-PERM-STATUS-1   OR
041600         MTSERB-STATUS IS EQUAL TO MTSERB-PERM-STATUS-2   OR
041700         MTSERB-STATUS IS EQUAL TO MTSERB-PERM-STATUS-3   OR
041800         MTSERB-STATUS IS EQUAL TO MTSERB-PERM-STATUS-4   OR
041900         MTSERB-STATUS IS EQUAL TO MTSERB-PERM-STATUS-5
042000         MOVE ZERO              TO MTSERB-TEMP-STATUS-1
042100         MOVE ZERO              TO MTSERB-TEMP-STATUS-2
042200     ELSE
042300         GO TO Z900-ABORT.
042400*
042500 S999-SA-EXIT.
042600     EXIT.
042700/
042800 Z000-PROGRAM-INITIALIZATION.
042900*
043000************************************************************
043100*    THE CALLING PROGRAM MUST SUPPLY THE PROGRAM ID TO     *
043200*    ENSURE THAT ANY SUBSEQUENT ABEND CAN BE TRACED TO     *
043300*    IT.  IF THE PROGRAM ID IS NOT SUPPLIED, THE ACCESS    *
043400*    ROUTINE ABENDS HERE.                                  *
043500************************************************************
043600*
043700     IF  SS02WS-ABEND-PROG-ID IS EQUAL TO SPACES
043800         MOVE '- BAD PROG NAME - MTSE'
043900                                 TO SS02WS-ABENDMSG8
044000         MOVE 'BADPRO'           TO SS02WS-ABEND-PROG-ID
044100         GO TO Z950-ABORT.
044200*
044300     MOVE SS02WS-ABEND-PROG-ID   TO WS-SM-PROG-ID.
044400*
044500*************************************************************
044600*    SINCE THIS ROUTINE IS PERFORMED ONLY ONCE DURING       *
044700*    THE EXECUTION OF A CALLING PROGRAM, THE FIRST          *
044800*    REQUEST MUST BE FOR AN OPEN.  SET THE ACCESS METHOD    *
044900*    (SEQENTIAL, DYNAMIC, OR RANDOM), OR ISSUE AN ABEND     *
045000*    IF THE REQUEST IS NOT FOR AN OPEN.                     *
045100*************************************************************
045200*
045300     IF  MTSERB-OPEN-INPUT    OR
045400         MTSERB-OPEN-OUTPUT   OR
045500         MTSERB-OPEN-IO
045600         MOVE 'N'                TO WS-FIRST-CALL-SW
045700     ELSE
045800         MOVE 'ILLEGAL ACCESS REQUEST'
045900                                 TO SS02WS-ABENDMSG8
046000         GO TO Z950-ABORT.
046100*
046200 Z099-PI-EXIT.
046300     EXIT.
046400*
046500 Z100-DISPLAY-THE-SUMMARY.
046600*
046700     MOVE WS-SC-READS            TO WS-SM-READS.
046800     MOVE WS-SC-WRITES           TO WS-SM-WRITES.
046900     MOVE WS-SC-REWRITES         TO WS-SM-REWRITES.
047000     DISPLAY WS-SUMMARY-MESSAGE.
047100*
047200     INITIALIZE WS-SUMMARY-COUNTERS.
047300*
047400 Z199-DTS-EXIT.
047500     EXIT.
047600/
047700 Z900-ABORT.
047800*
047900     MOVE 'SMTSE'                TO SS02WS-ABEND-CODE-X.
048000     MOVE MTSERB-STATUS          TO SS02WS-ABEND-STATUS.
048100     MOVE MTSERB-IO-REQUEST      TO WS-IO-REQUEST.
048200     MOVE WS-IO-REQUEST          TO SS02WS-ABEND-REQUEST.
048300*
048400 Z950-ABORT.
048500*
048600     PERFORM SS02PD-ABEND        THRU SS02PD-ABEND-EXIT.
048700*
048800 Z999-ABORT-EXIT.
048900     EXIT.
049000/
049100********************************
049200*    STANDARD ABEND ROUTINE    *
049300********************************
049400*
049500     COPY SS02PD.
049600*
