000100******************************************************************
000200*    ROUTINE TO LOAD MMRT RECORDS INTO A TABLE (RESERVES)        *
000300******************************************************************
000400*                                                                *
000500*    TO USE THE ROUTINES IN THIS AREA,                           *
000600*                                                                *
000700*    1. FILE ACCESS FOR THE MMRT FILE MUST BE IN YOUR PROGRAM.   *
000800*    2. COPY BOOKS MMRTTB4 AND MMRTIR MUST BE IN YOUR PROGRAM.   *
000900*    3. THE FILE "MMRT" MUST BE OPENED WITH DYNAMIC ACCESS       *
001000*                                                                *
001100******************************************************************
001200*                                                                *
001300*    TO USE THE LOAD ROUTINE,                                    *
001400*                                                                *
001500*    1. PROVIDE THE ORGANIZATION NUMBER WHOSE "MMRT" RECORDS     *
001600*       WILL BE LOADED INTO THE TABLE SPECIFIED IN COPY BOOK     *
001700*       MMRTTB4.  THE FIELD NAME FOR THE ORG NUMBER IS           *
001800*       MMRTTB4-START-ORG.                                       *
001900*       ALSO, YOU MAY SPECIFY A STARTING TABLE INDEX (DEFAULT    *
002000*       IS 1) AS AN OPTION.                                      *
002100*    2. OPTIONALLY, YOU MAY JUST PERFORM MMRTPX4-READ-AND-LOAD   *
002200*       IF YOU WANT TO AVOID THE "START" OF THE MMRT FILE.       *
002300*                                                                *
002400******************************************************************
002500 MMRTPX4-LOAD-MMRT-TABLE.
002600*
002700     MOVE SPACES                 TO MMRTTB4-TABLE-DATA.
002800     MOVE LOW-VALUES             TO MMRTIO-KEY.
002900     MOVE MMRTTB4-START-ORG
003000                                 TO MMRTIO-ORG.
003100*
003200     MOVE 'RT4A'                 TO SS02WS-ABEND-LOCATION.
003300     SET MMRTRB-START-GTE        TO TRUE.
003400     PERFORM MB00PD-MMRT-ACCESS  THRU MB00PD-MMRT-ACCESS-EXIT.
003500*
003600     MOVE 'RT4B'                 TO SS02WS-ABEND-LOCATION.
003700     SET MMRTRB-READ-SEQ         TO TRUE.
003800     PERFORM MB00PD-MMRT-ACCESS  THRU MB00PD-MMRT-ACCESS-EXIT.
003900*
004000     SET X-MMRTTB4               TO MMRTTB4-BEG-INDEX.
004100*
004200     PERFORM MMRTPX4-READ-AND-LOAD
004300        THRU MMRTPX4-RAL-EXIT
004400        UNTIL MMRTIO-ORG IS GREATER THAN MMRTTB4-START-ORG
004500           OR X-MMRTTB4  IS GREATER THAN MMRTTB4-MAX-ENTRIES
004600           OR MMRTIO-TRAILER.
004700*
004800 MMRTPX4-LMMRT-EXIT.
004900     EXIT.
005000/
005100 MMRTPX4-READ-AND-LOAD.
005200*
005300     MOVE MMRTIO-RECORD          TO MMRT-RECORD.
005400*
005500     IF  MMRT-HEADER
005600     OR  MMRT-TRAILER
005700     OR  MMRT-REC-INCOMPLETE
005800     OR  MMRT-REC-INACTIVE
005900     OR  MMRT-REC-PURGED
006000     OR  MMRT-TT-DISCOUNT
006100     OR  MMRT-TT-PARTICIPATION
006200     OR  MMRT-TT-RESERVE
006300     OR  MMRT-ORG IS NOT EQUAL TO MMRTTB4-START-ORG
006400         NEXT SENTENCE
006500     ELSE
006600         MOVE ZERO               TO MMRTTB4-COUNT (X-MMRTTB4)
006700         MOVE MMRT-RECORD        TO MMRTTB4-RECORD (X-MMRTTB4)
006800         SET X-MMRTTB4           UP BY 1.
006900*
007000     MOVE 'RT4C'                 TO SS02WS-ABEND-LOCATION.
007100     SET MMRTRB-READ-SEQ         TO TRUE.
007200     PERFORM MB00PD-MMRT-ACCESS  THRU MB00PD-MMRT-ACCESS-EXIT.
007300*
007400 MMRTPX4-RAL-EXIT.
007500     EXIT.
007600/
007700******************************************************************
007800*    ROUTINE TO SEARCH MMRT TABLE BY ORGANIZATION.  IF THERE ARE *
007900*    MORE RECORDS IN THE ORGANIZATION THAN THE TABLE PERMITS,    *
008000*    THE LEAST-USED ENTRY (BASED ON USAGE COUNT) WILL BE         *
008100*    REPLACED IN THE TABLE BY THE RANDOMLY READ REPLACEMENT.     *
008200******************************************************************
008300*                                                                *
008400*    TO USE THIS ROUTINE,                                        *
008500*                                                                *
008600*    1. PROVIDE THE ORGANIZATION NUMBER WHOSE "MMRT" RECORDS     *
008700*       WILL BE SEARCHED IN THE FIELD MMRTTB4-START-ORG.         *
008800*    2. PROVIDE THE TABLE NUMBER WHOSE "MMRT" RECORDS            *
008900*       WILL BE SEARCHED IN THE FIELD MMRTTB4-SEARCH-TABLE.      *
009000*    3. THE RESULTING TABLE TO BE USED WILL RESIDE IN THE        *
009100*       MMRT-RECORD.                                             *
009200*                                                                *
009300******************************************************************
009400 MMRTPX4-SEARCH-TABLE.
009500*
009600     SET X-MMRTTB4-SEARCH        TO 1.
009700     SEARCH MMRTTB4-TABLE VARYING X-MMRTTB4-SEARCH
009800         AT END
009900             PERFORM MMRTPX4-REPLACE-TABLE-ENTRY
010000                THRU MMRTPX4-RTE-EXIT
010100         WHEN MMRTTB4-END-OF-TABLE (X-MMRTTB4-SEARCH)
010200             MOVE MMRTIR-RECORD  TO MMRT-RECORD
010300         WHEN MMRTTB4-SEARCH-TABLE IS EQUAL TO
010400              MMRTTB4-TABLE-NBR (X-MMRTTB4-SEARCH)
010500             MOVE MMRTTB4-RECORD (X-MMRTTB4-SEARCH)
010600                                 TO MMRT-RECORD
010700             ADD 1               TO MMRTTB4-COUNT
010800                                    (X-MMRTTB4-SEARCH)
010900     END-SEARCH.
011000*
011100 MMRTPX4-ST-EXIT.
011200     EXIT.
011300/
011400 MMRTPX4-REPLACE-TABLE-ENTRY.
011500*
011600     SET X-MMRTTB4             TO 1.
011700     PERFORM
011800         VARYING X-MMRTTB4-SEARCH FROM 2 BY 1
011900         UNTIL   X-MMRTTB4-SEARCH IS GREATER THAN
012000                 MMRTTB4-MAX-ENTRIES
012100         EVALUATE TRUE
012200             WHEN MMRTTB4-COUNT (X-MMRTTB4-SEARCH) IS LESS THAN
012300                  MMRTTB4-COUNT (X-MMRTTB4)
012400                 SET X-MMRTTB4   TO X-MMRTTB4-SEARCH
012500         END-EVALUATE
012600     END-PERFORM.
012700*
012800     MOVE MMRTTB4-START-ORG      TO MMRTIO-ORG.
012900     MOVE MMRTTB4-SEARCH-TABLE   TO MMRTIO-TABLE-NBR.
013000     SET  MMRTIO-TT-VOLUME      TO TRUE.
013100     MOVE SS02WS-NO-RECORD-FOUND
013200                                 TO MMRTRB-TEMP-STATUS-1.
013300*
013400     MOVE 'RT4E'                 TO SS02WS-ABEND-LOCATION.
013500     SET MMRTRB-READ-RANDOM      TO TRUE.
013600     PERFORM MB00PD-MMRT-ACCESS  THRU MB00PD-MMRT-ACCESS-EXIT.
013700*
013800     IF  SS02WS-FS-NO-RECORD-FOUND
013900         MOVE MMRTIR-RECORD      TO MMRT-RECORD
014000     ELSE
014100         MOVE MMRTIO-RECORD      TO MMRT-RECORD
014200         IF  MMRT-HEADER
014300         OR  MMRT-TRAILER
014400         OR  MMRT-REC-INCOMPLETE
014500     OR  MMRT-REC-INACTIVE
014600         OR  MMRT-REC-PURGED
014700         OR  MMRT-ORG IS NOT EQUAL TO MMRTTB4-START-ORG
014800             MOVE MMRTIR-RECORD  TO MMRT-RECORD
014900         ELSE
015000             MOVE 1              TO MMRTTB4-COUNT
015100                                    (X-MMRTTB4)
015200             MOVE MMRTIO-RECORD  TO MMRTTB4-RECORD
015300                                    (X-MMRTTB4).
015400*
015500 MMRTPX4-RTE-EXIT.
015600     EXIT.
